@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
    Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
@@ -246,7 +246,7 @@ int yydebug = 1;
 typedef union YYSTYPE {
     char	*string;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
+/* Line 190 of yacc.c.  */
 #line 251 "yacc.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -258,7 +258,7 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
+/* Line 213 of yacc.c.  */
 #line 263 "yacc.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
@@ -274,14 +274,10 @@ typedef union YYSTYPE {
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
 #   endif
 #  endif
 # endif
@@ -919,20 +915,53 @@ do								\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -955,19 +984,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (yydebug)					\
-    yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
       yysymprint (stderr, 					\
-                  Token, Value);	\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -1034,8 +1057,7 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -1053,10 +1075,6 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -1138,15 +1156,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    {
-      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
-# ifdef YYPRINT
-      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
-    }
+    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
+
+# ifdef YYPRINT
+  if (yytype < YYNTOKENS)
+    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
   switch (yytype)
     {
       default:
@@ -1162,10 +1180,11 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yytype, yyvaluep)
+yydestruct (yymsg, yytype, yyvaluep)
+    const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -1173,6 +1192,10 @@ yydestruct (yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
+  if (!yymsg)
+    yymsg = "Deleting";
+  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
+
   switch (yytype)
     {
 
@@ -1200,10 +1223,10 @@ int yyparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1239,7 +1262,7 @@ yyparse ()
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -1291,6 +1314,8 @@ yyparse ()
   yyvsp = yyvs;
 
 
+  yyvsp[0] = yylval;
+
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1380,18 +1405,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1406,7 +1431,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1426,8 +1451,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1493,7 +1518,7 @@ yyreduce:
 #line 213 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = yyvsp[-2].string;
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
@@ -1501,7 +1526,7 @@ yyreduce:
 #line 218 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = yyvsp[-2].string;
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
@@ -1515,14 +1540,14 @@ yyreduce:
   case 7:
 #line 227 "yacc.y"
     {
-		    yyval.string = body_OBJECT_object(yyvsp[-2].string,yyvsp[0].string);
+		    (yyval.string) = body_OBJECT_object((yyvsp[-2].string),(yyvsp[0].string));
 		}
     break;
 
   case 8:
 #line 231 "yacc.y"
     {
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
@@ -1537,7 +1562,7 @@ yyreduce:
 #line 242 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = yyvsp[-3].string;
+		    (yyval.string) = (yyvsp[-3].string);
 		}
     break;
 
@@ -1559,7 +1584,7 @@ yyreduce:
 #line 255 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
@@ -1587,28 +1612,28 @@ yyreduce:
   case 17:
 #line 276 "yacc.y"
     {
-		    MakeTable(yyvsp[-4].string,yyvsp[-2].string, 0);
+		    MakeTable((yyvsp[-4].string),(yyvsp[-2].string), 0);
 		}
     break;
 
   case 18:
 #line 280 "yacc.y"
     {
-		    MakeTable(yyvsp[-6].string, yyvsp[-2].string, 0);
+		    MakeTable((yyvsp[-6].string), (yyvsp[-2].string), 0);
 		}
     break;
 
   case 19:
 #line 284 "yacc.y"
     {
-		    MakeTable(yyvsp[-7].string,yyvsp[-3].string,0);
+		    MakeTable((yyvsp[-7].string),(yyvsp[-3].string),0);
 		}
     break;
 
   case 20:
 #line 288 "yacc.y"
     {
-		    MakeTable(yyvsp[-7].string, yyvsp[-3].string, 0);
+		    MakeTable((yyvsp[-7].string), (yyvsp[-3].string), 0);
 		}
     break;
 
@@ -1629,147 +1654,147 @@ yyreduce:
   case 23:
 #line 300 "yacc.y"
     {
-		    MakeTable(yyvsp[-5].string, yyvsp[-2].string, 1);
+		    MakeTable((yyvsp[-5].string), (yyvsp[-2].string), 1);
 		}
     break;
 
   case 25:
 #line 308 "yacc.y"
     {
-			yyval.string = NULL;
+			(yyval.string) = NULL;
 	       	}
     break;
 
   case 26:
 #line 314 "yacc.y"
     {
-		    yyval.string = AddFont(yyvsp[-4].string, yyvsp[-2].string, yyvsp[0].string);
+		    (yyval.string) = AddFont((yyvsp[-4].string), (yyvsp[-2].string), (yyvsp[0].string));
 		}
     break;
 
   case 27:
 #line 318 "yacc.y"
     {
-		    yyval.string = AddFont(yyvsp[-2].string, yyvsp[0].string, NULL);
+		    (yyval.string) = AddFont((yyvsp[-2].string), (yyvsp[0].string), NULL);
 		}
     break;
 
   case 28:
 #line 324 "yacc.y"
     {
-		    yyval.string = CharSetName(NULL, yyvsp[0].string);
+		    (yyval.string) = CharSetName(NULL, (yyvsp[0].string));
 		}
     break;
 
   case 29:
 #line 328 "yacc.y"
     {
-		    yyval.string = CharSetName(yyvsp[-1].string, yyvsp[-2].string);
+		    (yyval.string) = CharSetName((yyvsp[-1].string), (yyvsp[-2].string));
 		}
     break;
 
   case 30:
 #line 334 "yacc.y"
     {
-		    yyval.string = CharSetRToL(yyvsp[0].string, (int)(long)yyvsp[-1].string);
+		    (yyval.string) = CharSetRToL((yyvsp[0].string), (int)(long)(yyvsp[-1].string));
 		}
     break;
 
   case 31:
 #line 338 "yacc.y"
     {
-		    yyval.string = CharSet16Bit(yyvsp[0].string, (int)(long)yyvsp[-1].string);
+		    (yyval.string) = CharSet16Bit((yyvsp[0].string), (int)(long)(yyvsp[-1].string));
 		}
     break;
 
   case 32:
 #line 342 "yacc.y"
     {
-		    yyval.string = MakeNewCharSet();
+		    (yyval.string) = MakeNewCharSet();
 		}
     break;
 
   case 33:
 #line 348 "yacc.y"
     {
-		    yyval.string = AddColor(yyvsp[-4].string,yyvsp[-2].string, yyvsp[0].string, 1);
+		    (yyval.string) = AddColor((yyvsp[-4].string),(yyvsp[-2].string), (yyvsp[0].string), 1);
 		}
     break;
 
   case 34:
 #line 352 "yacc.y"
     {
-		    yyval.string = AddColor(yyvsp[-2].string,yyvsp[0].string, NULL, 1);
+		    (yyval.string) = AddColor((yyvsp[-2].string),(yyvsp[0].string), NULL, 1);
 		}
     break;
 
   case 35:
 #line 356 "yacc.y"
     {
-		    yyval.string = AddColor(__MrmStore("\"_bg\""),yyvsp[0].string, NULL, 0);
+		    (yyval.string) = AddColor(__MrmStore("\"_bg\""),(yyvsp[0].string), NULL, 0);
 		}
     break;
 
   case 36:
 #line 360 "yacc.y"
     {
-		    yyval.string = AddColor(__MrmStore("\"_bg\""), yyvsp[-2].string, yyvsp[0].string, 0);
+		    (yyval.string) = AddColor(__MrmStore("\"_bg\""), (yyvsp[-2].string), (yyvsp[0].string), 0);
 		}
     break;
 
   case 37:
 #line 364 "yacc.y"
     {
-		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[0].string, NULL, 0);
+		    (yyval.string) = AddColor(__MrmStore("\"_fg\""), (yyvsp[0].string), NULL, 0);
 		}
     break;
 
   case 38:
 #line 368 "yacc.y"
     {
-		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[-2].string, yyvsp[0].string, 0);
+		    (yyval.string) = AddColor(__MrmStore("\"_fg\""), (yyvsp[-2].string), (yyvsp[0].string), 0);
 		}
     break;
 
   case 39:
 #line 372 "yacc.y"
     {
-		    yyval.string = AddColor(yyvsp[-5].string, yyvsp[-2].string, yyvsp[0].string, 0);
+		    (yyval.string) = AddColor((yyvsp[-5].string), (yyvsp[-2].string), (yyvsp[0].string), 0);
 		}
     break;
 
   case 40:
 #line 376 "yacc.y"
     {
-		    yyval.string = AddColor(yyvsp[-3].string, yyvsp[0].string, NULL, 0);
+		    (yyval.string) = AddColor((yyvsp[-3].string), (yyvsp[0].string), NULL, 0);
 		}
     break;
 
   case 41:
 #line 382 "yacc.y"
     {
-		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
+		    (yyval.string) = InsertString((yyvsp[-2].string), (yyvsp[0].string));
 		}
     break;
 
   case 42:
 #line 386 "yacc.y"
     {
-		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
+		    (yyval.string) = InsertString((yyvsp[-2].string), (yyvsp[0].string));
 		}
     break;
 
   case 43:
 #line 390 "yacc.y"
     {
-		    yyval.string = InsertString(NULL,yyvsp[0].string);
+		    (yyval.string) = InsertString(NULL,(yyvsp[0].string));
 		}
     break;
 
   case 44:
 #line 394 "yacc.y"
     {
-		    yyval.string = InsertString(NULL, yyvsp[0].string);
+		    (yyval.string) = InsertString(NULL, (yyvsp[0].string));
 		}
     break;
 
@@ -1784,7 +1809,7 @@ yyreduce:
 #line 404 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = yyvsp[-2].string;
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
@@ -1792,7 +1817,7 @@ yyreduce:
 #line 409 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = yyvsp[-4].string;
+		    (yyval.string) = (yyvsp[-4].string);
 		}
     break;
 
@@ -1807,7 +1832,7 @@ yyreduce:
 #line 418 "yacc.y"
     {
 		    __MrmWarn(LOC, "NO OP\n");
-		    yyval.string = yyvsp[-1].string;
+		    (yyval.string) = (yyvsp[-1].string);
 		}
     break;
 
@@ -1815,7 +1840,7 @@ yyreduce:
 #line 423 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = yyvsp[-3].string;
+		    (yyval.string) = (yyvsp[-3].string);
 		}
     break;
 
@@ -1892,45 +1917,45 @@ yyreduce:
   case 61:
 #line 474 "yacc.y"
     {
-		    AddAttributeList(yyvsp[-6].string, yyvsp[-2].string);
-		    yyval.string = NULL;
+		    AddAttributeList((yyvsp[-6].string), (yyvsp[-2].string));
+		    (yyval.string) = NULL;
 		}
     break;
 
   case 62:
 #line 479 "yacc.y"
     {
-		    AddControlList(yyvsp[-6].string, yyvsp[-2].string);
-		    yyval.string = NULL;
+		    AddControlList((yyvsp[-6].string), (yyvsp[-2].string));
+		    (yyval.string) = NULL;
 		}
     break;
 
   case 63:
 #line 484 "yacc.y"
     {
-		    AddCallbackList(yyvsp[-6].string, yyvsp[-2].string);
-		    yyval.string = NULL;
+		    AddCallbackList((yyvsp[-6].string), (yyvsp[-2].string));
+		    (yyval.string) = NULL;
 		}
     break;
 
   case 64:
 #line 489 "yacc.y"
     {
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
   case 65:
 #line 495 "yacc.y"
     {
-		    yyval.string = (char *)arglist_arglist_ID_addexpr(yyvsp[-4].string, yyvsp[-3].string, yyvsp[-1].string);
+		    (yyval.string) = (char *)arglist_arglist_ID_addexpr((yyvsp[-4].string), (yyvsp[-3].string), (yyvsp[-1].string));
 		}
     break;
 
   case 66:
 #line 499 "yacc.y"
     {
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
@@ -1944,8 +1969,8 @@ yyreduce:
   case 68:
 #line 509 "yacc.y"
     {
-		    ID_ID_features(yyvsp[-6].string,yyvsp[-4].string,yyvsp[-2].string);
-		    yyval.string = yyvsp[-2].string;
+		    ID_ID_features((yyvsp[-6].string),(yyvsp[-4].string),(yyvsp[-2].string));
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
@@ -1960,8 +1985,8 @@ yyreduce:
 #line 518 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    ID_ID_features(yyvsp[-7].string, yyvsp[-4].string, yyvsp[-2].string);
-		    yyval.string = yyvsp[-2].string;
+		    ID_ID_features((yyvsp[-7].string), (yyvsp[-4].string), (yyvsp[-2].string));
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
@@ -1982,38 +2007,38 @@ yyreduce:
   case 73:
 #line 534 "yacc.y"
     {
-		    features_controls(yyvsp[-1].string,yyvsp[0].string);
-		    yyval.string = yyvsp[-1].string;
+		    features_controls((yyvsp[-1].string),(yyvsp[0].string));
+		    (yyval.string) = (yyvsp[-1].string);
 		}
     break;
 
   case 74:
 #line 539 "yacc.y"
     {
-		    features_arguments(yyvsp[-1].string,yyvsp[0].string);
-		    yyval.string = yyvsp[-1].string;
+		    features_arguments((yyvsp[-1].string),(yyvsp[0].string));
+		    (yyval.string) = (yyvsp[-1].string);
 		}
     break;
 
   case 75:
 #line 544 "yacc.y"
     {
-		    features_callbacks(yyvsp[-1].string,yyvsp[0].string);
-		    yyval.string = yyvsp[-1].string;
+		    features_callbacks((yyvsp[-1].string),(yyvsp[0].string));
+		    (yyval.string) = (yyvsp[-1].string);
 		}
     break;
 
   case 76:
 #line 549 "yacc.y"
     {
-		    yyval.string = (char *)Features_NULL();
+		    (yyval.string) = (char *)Features_NULL();
 		}
     break;
 
   case 77:
 #line 555 "yacc.y"
     {
-		    yyval.string = yyvsp[-2].string;
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
@@ -2021,21 +2046,21 @@ yyreduce:
 #line 559 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
   case 79:
 #line 566 "yacc.y"
     {
-		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-3].string,yyvsp[-2].string,yyvsp[-1].string,1);
+		    (yyval.string) = (char *)controllist_controllist_ID_ID((yyvsp[-3].string),(yyvsp[-2].string),(yyvsp[-1].string),1);
 		}
     break;
 
   case 80:
 #line 570 "yacc.y"
     {
-		    yyval.string = (char *)control_list_ID_features(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-2].string, 1);
+		    (yyval.string) = (char *)control_list_ID_features((yyvsp[-5].string), (yyvsp[-4].string), (yyvsp[-2].string), 1);
 		}
     break;
 
@@ -2043,14 +2068,14 @@ yyreduce:
 #line 574 "yacc.y"
     {   /* $2 may be wrong for this type of call */
 		    /* I confused this rule for the next one */
-		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string, yyvsp[-5].string, yyvsp[-2].string, 0);
+		    (yyval.string) = (char *)control_list_ID_features((yyvsp[-6].string), (yyvsp[-5].string), (yyvsp[-2].string), 0);
 		}
     break;
 
   case 82:
 #line 579 "yacc.y"
     {
-		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string,yyvsp[-4].string, yyvsp[-2].string, 0);
+		    (yyval.string) = (char *)control_list_ID_features((yyvsp[-6].string),(yyvsp[-4].string), (yyvsp[-2].string), 0);
 		}
     break;
 
@@ -2064,14 +2089,14 @@ yyreduce:
   case 84:
 #line 587 "yacc.y"
     {
-		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-4].string,yyvsp[-2].string,yyvsp[-1].string,0);
+		    (yyval.string) = (char *)controllist_controllist_ID_ID((yyvsp[-4].string),(yyvsp[-2].string),(yyvsp[-1].string),0);
 		}
     break;
 
   case 85:
 #line 591 "yacc.y"
     {
-		    yyval.string = InheritControls(yyvsp[-3].string, yyvsp[-1].string);
+		    (yyval.string) = InheritControls((yyvsp[-3].string), (yyvsp[-1].string));
 		}
     break;
 
@@ -2085,98 +2110,98 @@ yyreduce:
   case 87:
 #line 599 "yacc.y"
     {
-			yyval.string = NULL;
+			(yyval.string) = NULL;
 		}
     break;
 
   case 88:
 #line 605 "yacc.y"
     {
-		    yyval.string = yyvsp[-2].string;
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
   case 89:
 #line 611 "yacc.y"
     {
-		    yyval.string = arglist_arglist_ID_addexpr(yyvsp[-4].string,yyvsp[-3].string,yyvsp[-1].string);
+		    (yyval.string) = arglist_arglist_ID_addexpr((yyvsp[-4].string),(yyvsp[-3].string),(yyvsp[-1].string));
 		}
     break;
 
   case 90:
 #line 615 "yacc.y"
     {
-		    yyval.string = WidgetArgument(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-1].string);
+		    (yyval.string) = WidgetArgument((yyvsp[-5].string), (yyvsp[-4].string), (yyvsp[-1].string));
 	     	}
     break;
 
   case 91:
 #line 619 "yacc.y"
     {
-		    yyval.string = InheritArgument(yyvsp[-3].string, yyvsp[-1].string);
+		    (yyval.string) = InheritArgument((yyvsp[-3].string), (yyvsp[-1].string));
 		}
     break;
 
   case 92:
 #line 623 "yacc.y"
     {
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
   case 93:
 #line 629 "yacc.y"
     {
-		    yyval.string = yyvsp[0].string;
+		    (yyval.string) = (yyvsp[0].string);
 		}
     break;
 
   case 94:
 #line 633 "yacc.y"
     {
-		    yyval.string = Subtract(yyvsp[-2].string,yyvsp[0].string);
+		    (yyval.string) = Subtract((yyvsp[-2].string),(yyvsp[0].string));
 		}
     break;
 
   case 95:
 #line 637 "yacc.y"
     {
-		    yyval.string = Add(yyvsp[-2].string,yyvsp[0].string);
+		    (yyval.string) = Add((yyvsp[-2].string),(yyvsp[0].string));
 		}
     break;
 
   case 96:
 #line 641 "yacc.y"
     {
-		    yyval.string = AppendStrings(yyvsp[-2].string, yyvsp[0].string);
+		    (yyval.string) = AppendStrings((yyvsp[-2].string), (yyvsp[0].string));
 		}
     break;
 
   case 97:
 #line 647 "yacc.y"
     {
-		    yyval.string = yyvsp[0].string;
+		    (yyval.string) = (yyvsp[0].string);
 		}
     break;
 
   case 98:
 #line 651 "yacc.y"
     {
-		    yyval.string = Multiply(yyvsp[-2].string,yyvsp[0].string);
+		    (yyval.string) = Multiply((yyvsp[-2].string),(yyvsp[0].string));
 		}
     break;
 
   case 99:
 #line 655 "yacc.y"
     {
-		    yyval.string = Divide(yyvsp[-2].string,yyvsp[0].string);
+		    (yyval.string) = Divide((yyvsp[-2].string),(yyvsp[0].string));
 		}
     break;
 
   case 100:
 #line 661 "yacc.y"
     {
-		    yyval.string = (char *) expr_ID(yyvsp[0].string);
+		    (yyval.string) = (char *) expr_ID((yyvsp[0].string));
 		}
     break;
 
@@ -2184,57 +2209,57 @@ yyreduce:
 #line 665 "yacc.y"
     {
 		    __MrmWarn(LOC, "Font Unit not implemented yet\n");
-		    yyval.string = (char *) prim_exp(yyvsp[-1].string);
+		    (yyval.string) = (char *) prim_exp((yyvsp[-1].string));
 		}
     break;
 
   case 102:
 #line 670 "yacc.y"
     {
-		    yyval.string = (char *)prim_exp(yyvsp[0].string);
+		    (yyval.string) = (char *)prim_exp((yyvsp[0].string));
 		}
     break;
 
   case 103:
 #line 674 "yacc.y"
     {
-		    fprintf(stderr,"BLAB BLAB ID = %s\n", yyvsp[0].string);
-		    yyval.string = (char *) expr_STRING(yyvsp[0].string, yyvsp[-1].string,/*Compound?*/ False);
+		    fprintf(stderr,"BLAB BLAB ID = %s\n", (yyvsp[0].string));
+		    (yyval.string) = (char *) expr_STRING((yyvsp[0].string), (yyvsp[-1].string),/*Compound?*/ False);
 		}
     break;
 
   case 104:
 #line 679 "yacc.y"
     {
-		    yyval.string = (char *) expr_STRING(yyvsp[0].string, NULL, /*Compound?*/ False);
+		    (yyval.string) = (char *) expr_STRING((yyvsp[0].string), NULL, /*Compound?*/ False);
 		}
     break;
 
   case 105:
 #line 683 "yacc.y"
     {
-		    yyval.string = (char *) expr_BOOL(yyvsp[0].string);
+		    (yyval.string) = (char *) expr_BOOL((yyvsp[0].string));
 		}
     break;
 
   case 106:
 #line 687 "yacc.y"
     {
-		    yyval.string = (char *) keysym(yyvsp[-1].string);
+		    (yyval.string) = (char *) keysym((yyvsp[-1].string));
 		}
     break;
 
   case 107:
 #line 691 "yacc.y"
     {
-		    yyval.string = (char *) font(yyvsp[-1].string);
+		    (yyval.string) = (char *) font((yyvsp[-1].string));
 		}
     break;
 
   case 108:
 #line 695 "yacc.y"
     {
-		    yyval.string = (char *) keysym(yyvsp[-1].string);
+		    (yyval.string) = (char *) keysym((yyvsp[-1].string));
 		}
     break;
 
@@ -2242,63 +2267,63 @@ yyreduce:
 #line 699 "yacc.y"
     {
 		    __MrmWarn(LOC,"NO OP\n");
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
   case 110:
 #line 704 "yacc.y"
     {	
-		    yyval.string = (char *) bitmap(yyvsp[-1].string);
+		    (yyval.string) = (char *) bitmap((yyvsp[-1].string));
 		}
     break;
 
   case 111:
 #line 708 "yacc.y"
     {
-		    yyval.string = (char *) pixmap(yyvsp[-3].string, yyvsp[-1].string);
+		    (yyval.string) = (char *) pixmap((yyvsp[-3].string), (yyvsp[-1].string));
 		}
     break;
 
   case 112:
 #line 712 "yacc.y"
     {
-		    yyval.string = pixmap(NULL,yyvsp[-1].string);
+		    (yyval.string) = pixmap(NULL,(yyvsp[-1].string));
 		}
     break;
 
   case 113:
 #line 716 "yacc.y"
     {
-		    yyval.string = color(NULL, yyvsp[-5].string, yyvsp[-3].string, yyvsp[-1].string);
+		    (yyval.string) = color(NULL, (yyvsp[-5].string), (yyvsp[-3].string), (yyvsp[-1].string));
 		}
     break;
 
   case 114:
 #line 720 "yacc.y"
     {
-		    yyval.string = color(yyvsp[-1].string, 0, 0, 0);
+		    (yyval.string) = color((yyvsp[-1].string), 0, 0, 0);
 		}
     break;
 
   case 115:
 #line 724 "yacc.y"
     {
-		    yyval.string = color(yyvsp[-3].string, 0, 0, 0); /* For Now  FIX ME */
+		    (yyval.string) = color((yyvsp[-3].string), 0, 0, 0); /* For Now  FIX ME */
 		}
     break;
 
   case 116:
 #line 728 "yacc.y"
     {
-		    yyval.string = yyvsp[0].string;
+		    (yyval.string) = (yyvsp[0].string);
 		}
     break;
 
   case 117:
 #line 732 "yacc.y"
     {	
-		    yyval.string = yyvsp[-1].string;
+		    (yyval.string) = (yyvsp[-1].string);
 		}
     break;
 
@@ -2306,52 +2331,52 @@ yyreduce:
 #line 738 "yacc.y"
     {
 		    /* string, separate, IsAddress */
-		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,False);
+		    (yyval.string) = (char *) expr_STRING_Compound((yyvsp[-5].string),(int)(long)(yyvsp[-1].string),False);
 		}
     break;
 
   case 119:
 #line 743 "yacc.y"
     {
-		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,True);
+		    (yyval.string) = (char *) expr_STRING_Compound((yyvsp[-5].string),(int)(long)(yyvsp[-1].string),True);
 		}
     break;
 
   case 120:
 #line 747 "yacc.y"
     {
-		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, True);
+		    (yyval.string) = (char *) expr_STRING_Compound((yyvsp[-1].string), False, True);
 		}
     break;
 
   case 121:
 #line 751 "yacc.y"
     {
-		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, False);
+		    (yyval.string) = (char *) expr_STRING_Compound((yyvsp[-1].string), False, False);
 		}
     break;
 
   case 122:
 #line 757 "yacc.y"
     {
-		    yyval.string = yyvsp[-2].string;
+		    (yyval.string) = (yyvsp[-2].string);
 		}
     break;
 
   case 123:
 #line 761 "yacc.y"
     {
-		    yyval.string = InheritCallback(yyvsp[-1].string);
+		    (yyval.string) = InheritCallback((yyvsp[-1].string));
 		}
     break;
 
   case 124:
 #line 767 "yacc.y"
     {
-		    yyval.string = (char *)callbacklist_callbacklist_PROCID_arglist(yyvsp[-8].string,
-									  yyvsp[-7].string,
-									  yyvsp[-4].string,
-									  yyvsp[-2].string);
+		    (yyval.string) = (char *)callbacklist_callbacklist_PROCID_arglist((yyvsp[-8].string),
+									  (yyvsp[-7].string),
+									  (yyvsp[-4].string),
+									  (yyvsp[-2].string));
 		}
     break;
 
@@ -2365,7 +2390,7 @@ yyreduce:
   case 126:
 #line 778 "yacc.y"
     {
-		    yyval.string = NULL;
+		    (yyval.string) = NULL;
 		}
     break;
 
@@ -2385,64 +2410,64 @@ yyreduce:
   case 129:
 #line 793 "yacc.y"
     {
-		    yyval.string = Parameter(yyvsp[-2].string, prim_exp(yyvsp[0].string));
+		    (yyval.string) = Parameter((yyvsp[-2].string), prim_exp((yyvsp[0].string)));
 		}
     break;
 
   case 130:
 #line 797 "yacc.y"
     {
-		    yyval.string = Parameter(yyvsp[-2].string, expr_ID(yyvsp[0].string));
+		    (yyval.string) = Parameter((yyvsp[-2].string), expr_ID((yyvsp[0].string)));
 		}
     break;
 
   case 131:
 #line 801 "yacc.y"
     {
-		    yyval.string = Parameter(yyvsp[-2].string, expr_STRING(yyvsp[0].string, NULL, 0));
+		    (yyval.string) = Parameter((yyvsp[-2].string), expr_STRING((yyvsp[0].string), NULL, 0));
 		}
     break;
 
   case 132:
 #line 805 "yacc.y"
     {
-		    yyval.string = Parameter(NULL, prim_exp(yyvsp[0].string));
+		    (yyval.string) = Parameter(NULL, prim_exp((yyvsp[0].string)));
 		}
     break;
 
   case 133:
 #line 809 "yacc.y"
     {
-		    yyval.string = Parameter(NULL, expr_ID(yyvsp[0].string));
+		    (yyval.string) = Parameter(NULL, expr_ID((yyvsp[0].string)));
 		}
     break;
 
   case 134:
 #line 813 "yacc.y"
     {
-		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 0));
+		    (yyval.string) = Parameter(NULL, expr_STRING((yyvsp[0].string), NULL, 0));
 		}
     break;
 
   case 135:
 #line 817 "yacc.y"
     {
-		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 1));
+		    (yyval.string) = Parameter(NULL, expr_STRING((yyvsp[0].string), NULL, 1));
 		}
     break;
 
   case 136:
 #line 821 "yacc.y"
     {
-		    yyval.string = Parameter(NULL, NULL);
+		    (yyval.string) = Parameter(NULL, NULL);
 		}
     break;
 
 
     }
 
-/* Line 1010 of yacc.c.  */
-#line 2446 "yacc.c"
+/* Line 1037 of yacc.c.  */
+#line 2471 "yacc.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2542,7 +2567,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2552,23 +2577,22 @@ yyerrlab:
 	  if (yychar == YYEOF)
 	     for (;;)
 	       {
+
 		 YYPOPSTACK;
 		 if (yyssp == yyss)
 		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-		 yydestruct (yystos[*yyssp], yyvsp);
+		 yydestruct ("Error: popping",
+                             yystos[*yyssp], yyvsp);
 	       }
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-	  yydestruct (yytoken, &yylval);
+	  yydestruct ("Error: discarding", yytoken, &yylval);
 	  yychar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2585,7 +2609,7 @@ yyerrorlab:
      goto yyerrorlab;
 #endif
 
-  yyvsp -= yylen;
+yyvsp -= yylen;
   yyssp -= yylen;
   yystate = *yyssp;
   goto yyerrlab1;
@@ -2615,8 +2639,8 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-      yydestruct (yystos[yystate], yyvsp);
+
+      yydestruct ("Error: popping", yystos[yystate], yyvsp);
       YYPOPSTACK;
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -2625,11 +2649,12 @@ yyerrlab1:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++yyvsp = yylval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
+
   yystate = yyn;
   goto yynewstate;
 
@@ -2645,6 +2670,9 @@ yyacceptlab:
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
 yyabortlab:
+  yydestruct ("Error: discarding lookahead",
+              yytoken, &yylval);
+  yychar = YYEMPTY;
   yyresult = 1;
   goto yyreturn;
 
