@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.0/Xm/LabelGP.h,v 1.1 2002/03/02 13:49:27 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/LabelGP.h,v 1.1 2004/08/28 19:23:25 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995-2000, 2002 LessTif Development Team
@@ -47,7 +47,7 @@ typedef struct _XmLabelGCacheObjClassRec {
 	XmLabelGCacheObjClassPart label_class_cache;
 } XmLabelGCacheObjClassRec;
 
-extern XmLabelGCacheObjClassRec xmLabelGCacheObjClassRec;
+XMLIBEXPORT extern XmLabelGCacheObjClassRec xmLabelGCacheObjClassRec;
 
 typedef struct _XmLabelGCacheObjPart {
 	unsigned char label_type;
@@ -90,7 +90,7 @@ typedef struct _XmLabelGadgetClassRec {
     XmLabelGadgetClassPart label_class;
 } XmLabelGadgetClassRec;
 
-extern XmLabelGadgetClassRec xmLabelGadgetClassRec;
+XMLIBEXPORT extern XmLabelGadgetClassRec xmLabelGadgetClassRec;
 
 typedef struct _XmLabelGadgetPart {
 	_XmString _label;
