@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.0/Xm/TransferT.h,v 1.1 2000/11/07 12:33:13 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/TransferT.h,v 1.1 2004/08/28 19:23:27 dannybackx Exp $
  *
  * Copyright (C) 2000 LessTif Development Team
  *
@@ -41,7 +41,7 @@ typedef struct {
 } XmTransferTraitRec, *XmTransferTrait;
 
 
-extern XrmQuark	XmQTtransfer;
+XMLIBEXPORT extern XrmQuark	XmQTtransfer;
 
 
 #ifdef __cplusplus
