@@ -1,6 +1,6 @@
 /**
  *
- * $Id: VendorS.h,v 1.2 2000/09/23 14:51:41 amai Exp $
+ * $Id: VendorS.h,v 1.1 2004/08/28 19:23:27 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2000 LessTif Development Team
@@ -32,7 +32,7 @@
 extern "C" {
 #endif
 
-extern WidgetClass vendorShellWidgetClass;
+XMLIBEXPORT extern WidgetClass vendorShellWidgetClass;
 
 typedef struct _XmVendorShellRec       * XmVendorShellWidget;
 typedef struct _XmVendorShellClassRec      * XmVendorShellWidgetClass;
@@ -43,7 +43,7 @@ typedef struct _XmVendorShellClassRec      * XmVendorShellWidgetClass;
 
 /* window manager stuff */
 
-Boolean XmIsMotifWMRunning(Widget shell);
+XMLIBEXPORT Boolean XmIsMotifWMRunning(Widget shell);
 
 #ifdef __cplusplus
 }
