@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DebugUtil.h,v 1.2 2005/03/28 08:24:56 dannybackx Exp $
+ * $Id: DebugUtil.h,v 1.5 2006/04/19 18:42:22 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995-2002, 2004, 2005 LessTif Development Team
@@ -57,12 +57,11 @@ void _LtDebugPrintArgList(const char *fn, Widget w, ArgList al, int n, Boolean G
 /*
  * Convert types into string format
  */
+const char *_LtDebugFrameChildType2String(int action);
 const char *_LtDebugFocusDetail2String(int type);
 const char *_LtDebugFocusMode2String(int type);
 const char *_LtDebugEventType2String(int type);
-#if XmVERSION > 1
 const char *_LtDebugComboBoxType2String(unsigned char type);
-#endif
 const char *_LtDebugGeoAction2String(int action);
 const char *_LtDebugDeleteResponse2String(int d);
 const char *_LtDebugGeometryResult2String(XtGeometryResult r);
@@ -97,6 +96,11 @@ const char *_LtDebugResizePolicy2String(int n);
 const char *_LtDebugScrollingPolicy2String(unsigned char r);
 const char *_LtDebugDialogStyle2String(int a);
 
+const char * _LtDebugVisualPolicy2String(int);
+const char * _LtDebugScrollPolicy2String(int);
+const char * _LtDebugXmStringComponentType2String(int);
+
+
 /*
  * Debug printing functions
  */
@@ -104,9 +108,9 @@ void _LtDebug(const char *fn, Widget w, const char *fmt, ...);
 void _LtDebug2(const char *fn, Widget w, Widget c, const char *fmt, ...);
 void _LtDebug0(const char *fn, Widget w, const char *fmt, ...);
 void _LtDebugPrintString(const char *s);
-void _LtDebugAction(const char *fn, Widget w, const String action,
-		const String *params, const Cardinal *num_params);
-void _LtDebugPrintRenderTable(char *, XmRenderTable);
+void _LtDebugAction(const char *, Widget, const String, const String *, const Cardinal *);
+void _LtDebugPrintRenderTable(const char *, Widget, char *, XmRenderTable);
+void _LtDebugPrintManagedChildren(const char *, Widget, const char *);
 
 #ifdef LESSTIF_PRODUCTION
 #define	_LtDebugInDebug(x, y)	False
