@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/XmI/XmI.h,v 1.1 2004/08/28 19:23:36 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/XmI/XmI.h,v 1.4 2006/04/19 18:42:22 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -71,17 +71,14 @@ void __XmRenderTableFinalise(Widget, XmFontList, _XmString);
 void _XmRenderTableFinalise(Widget, XmFontList, XmString);
 void _XmRenderTableFinaliseTag(Widget, XmFontList, char *);
 
-#if (XmVERSION > 1)
 XmRenderTable _XmRenderTablePushRendition(XmRenderTable, XmRendition);
 XmRenderTable _XmRenderTablePopRendition(XmRenderTable, XmRendition);
-#endif
 
 typedef struct __XmRenditionRec {
 	char		*tag;
 	XmFontType	type;
 	XFontSet	font;
 	int		count;
-#if (XmVERSION > 1)
 	Pixel		rendition_background,
 			rendition_foreground;
 	char		*font_name;
@@ -107,7 +104,6 @@ typedef struct __XmRenditionRec {
 	int		font_average_width,	/* Calculated by LessTif,	*/
 			font_average_height;	/* depend only on xft_font	*/
 #endif
-#endif
 } *_XmRendition;
 
 struct __XmRenderTableRec {
@@ -159,7 +155,6 @@ struct _XmtStringContextRec {
     Boolean separator;
 };
 
-#if (XmVERSION > 1)
 struct __XmParseMappingRec {
 	XtPointer	client_data;
 	XmIncludeStatus	include_status;
@@ -168,7 +163,6 @@ struct __XmParseMappingRec {
 	XmTextType	pattern_type;
 	XmString	substitute;
 };
-#endif
 
 /* ADDED FOR EXTERNAL FORM */
 #define XmSTRING_COMPONENT_XMSTRING     (XmSTRING_COMPONENT_LOCALE_TEXT + 1)
@@ -185,11 +179,6 @@ typedef unsigned char XmIMInputPolicy;
 #define	IP_PER_SHELL		2
 
 void _XmImSendSpot(Widget w);
-#if XmVERSION == 1
-XIC XmImGetXIC(Widget w, XmIMInputPolicy input_policy,
-           ArgList args, Cardinal num_args);
-XIC XmImSetXIC(Widget w, XIC xic);
-#endif
 
 /*
  * GENERIC PROTOTYPES
@@ -237,6 +226,10 @@ void _XmCascadePixmapDefault(Widget w, int offset, XrmValue *val);
 /* Find the VendorShell Extension Object */
 Widget _LtFindVendorExt(Widget);
 
+#ifdef USE_XFT
+extern void _XmXftSetClipRectangles(Widget w, Position x, Position y,
+	XRectangle *rects, int n);
+#endif
 /*
  * fontlist prototypes
  */
@@ -346,9 +339,7 @@ void _XmManagerUninstallMnemonic(Widget m, Widget w);
 
 
 /* for MapEvent.c */
-#if (XmVERSION > 1)
- int _XmMapKeyEvents(String str, int **eventType, KeySym **keysym, Modifiers **modifiers);
-#endif
+int _XmMapKeyEvents(String str, int **eventType, KeySym **keysym, Modifiers **modifiers);
 
 /* for ScrolledW */
 /* T. Straumann: */
@@ -456,67 +447,34 @@ void _XmDrawSquareButton(Widget w, int x, int y, int size,
                          GC top_gc, GC bottom_gc, GC select_gc, Boolean fill);
 void _XmDrawDiamondButton(Widget w, int x, int y, int size,
                           GC top_gc, GC bottom_gc, GC select_gc, Boolean fill);
-#if XmVERSION >= 2
+
 void _XmDrawPolygonShadow(Display *display, Drawable drawable,
                           GC top_gc, GC bottom_gc, XPoint *points, int point_count,
                           Dimension shadow_thickness, unsigned char shadow_type);
-#endif
 
 
-#if XmVERSION >= 2
-/* from Xmos.c: 
-   private, but exported stuff from Motif 1.2 which is used within LessTif,
-   also for the 2.x libs */
-
+/*
+ * From Xmos.c: private, but exported stuff from Motif 1.2
+ * which is used within LessTif, also for the 2.x libs
+ */
 XmString 
-_XmOSGetLocalizedString(char *reserved,
-			Widget w,
-			String resourceName,
-			String value);
-
+_XmOSGetLocalizedString(char *reserved, Widget w, String resourceName, String value);
 int _XmMicroSleep(long secs);
-
 String _XmOSGetHomeDirName(void);
-String _XmOSInitPath(String file_name,
-                     String env_pathname,
-                     Boolean *user_path);
-
-void 
-_XmSleep(unsigned int secs);
-
+String _XmOSInitPath(String file_name, String env_pathname, Boolean *user_path);
+void _XmSleep(unsigned int secs);
 String _XmOSGetHomeDirName(void);
-
-int 
-_XmOSFileCompare(XmConst void *sp1,
-                 XmConst void *sp2);
-
-
-void 
-_XmOSQualifyFileSpec(String dirSpec,
-                     String filterSpec,
-                     String *pQualifiedDir,
-                     String *pQualifiedPattern);
-
-String 
-_XmOSFindPatternPart(String fileSpec);
-
-void 
-_XmOSGetDirEntries(String qualifiedDir,
-                   String matchPattern,
-                   unsigned char fileType,
-                   Boolean matchDotsLiterally,
-                   Boolean listWithFullPath,
-                   String **pEntries,
-                   unsigned int *pNumEntries,
-                   unsigned int *pNumAlloc);
-
-void 
-_XmOSBuildFileList(String dirPath,
-                   String pattern,
-                   unsigned char typeMask,
-                   String **pEntries,
-                   unsigned int *pNumEntries,
-                   unsigned int *pNumAlloc);
+int _XmOSFileCompare(XmConst void *sp1, XmConst void *sp2);
+void _XmOSQualifyFileSpec(String dirSpec, String filterSpec,
+		String *pQualifiedDir, String *pQualifiedPattern);
+String _XmOSFindPatternPart(String fileSpec);
+void _XmOSGetDirEntries(String qualifiedDir, String matchPattern,
+		unsigned char fileType, Boolean matchDotsLiterally,
+		Boolean listWithFullPath, String **pEntries,
+		unsigned int *pNumEntries, unsigned int *pNumAlloc);
+void _XmOSBuildFileList(String dirPath, String pattern,
+		unsigned char typeMask, String **pEntries,
+		unsigned int *pNumEntries, unsigned int *pNumAlloc);
 
 
 /* The following are definitions for 2.x stuff, work in progress.
@@ -537,8 +495,6 @@ struct _XmTabListRec {
 /* defined in Trait.c, but used outside; not a symbol from OSF/Motif */
 void _XmInitTraits(void);
 
-#endif /* XmVERSION >= 2 */
-
 #ifdef	USE_XFT
 /*
  * XftDraw cache functions, implemented in lib/Xm/FontList.c
