@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/DialogS.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/DialogS.c,v 1.2 2004/09/29 17:48:41 dannybackx Exp $
  *
  * derived from Xt Vendor class.c 
  *
@@ -26,7 +26,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/DialogS.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/DialogS.c,v 1.2 2004/09/29 17:48:41 dannybackx Exp $";
 
 /*
  * This controls questionable behavior.  It will go away
@@ -437,9 +437,14 @@ change_managed(Widget w)
 	    Widget p;
 
 	    p = XtParent(w);
-
-	    px = XtX(p) + (XtWidth(p) - XtWidth(child)) / 2;
-	    py = XtY(p) + (XtHeight(p) - XtHeight(child)) / 2;
+	    /* XXX XtX and XtY give position of parent relative to its parent.
+	      we need it's position relative to the screen. Let XtTranslateCoords do it. */
+	    px = (XtWidth(p) - XtWidth(child)) / 2;
+	    py = (XtHeight(p) - XtHeight(child)) / 2;
+	    if (XtIsRealized(p))
+	    {
+	       XtTranslateCoords(p, px, py, &px, &py);
+	    }
 
 	    DEBUGOUT(_LtDebug(__FILE__, w, "def. pos. %d %d\n", px, py));
 
