@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Display.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $
+ * $Id: Display.c,v 1.2 2005/01/04 17:07:05 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1997, 1998, 1999, 2000, 2001, 2002, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Display.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $";
+static const char rcsid[] = "$Id: Display.c,v 1.2 2005/01/04 17:07:05 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -77,7 +77,6 @@ static XtResource resources[] =
 	sizeof(String), Offset(bindingsString),
 	XmRImmediate, (XtPointer)NULL	/* adhere to compatibility! */
     },
-#if (XmVERSION > 1)
     {
 	XmNnoFontCallback, XmCCallback, XmRCallback,
 	sizeof(XtCallbackList), Offset(no_font_callback),
@@ -88,7 +87,6 @@ static XtResource resources[] =
 	sizeof(XtCallbackList), Offset(no_rendition_callback),
 	XmRImmediate, (XtPointer)NULL
     },
-#endif
 };
 
 static void class_initialize(void);
@@ -257,8 +255,7 @@ DisplaySuicide(Widget w, XtPointer ClientData, XtPointer CallData)
 {
     Display *Dsp;
 
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)ClientData,
-		      "XmDisplay Connection Close-Down\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)ClientData, "XmDisplay Connection Close-Down\n"));
 
     Dsp = XtDisplay((Widget)ClientData);
 
@@ -409,29 +406,29 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
+	if (CoreBeingDestroyed(w))
+		DEBUGOUT(_LtDebug(__FILE__, w, "Destroy(being_destroyed)\n"));
+	else {
+		DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
 
-    if (CoreBeingDestroyed(w))
-	DEBUGOUT(_LtDebug(__FILE__, w, "Destroy(being_destroyed)\n"));
-    else {
-	DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
+		/* Hack */
+		return;
+	}
 
-	/* Hack */
-	return;
-    }
+	if (((XmDisplayRec *)w)->display.bindings) {
+		XtFree((char *)((XmDisplayRec *)w)->display.bindings);
+		((XmDisplayRec *)w)->display.bindings = NULL;
+	}
 
-    if (((XmDisplayRec *)w)->display.bindings)
-    {
-	XtFree((char *)((XmDisplayRec *)w)->display.bindings);
-	((XmDisplayRec *)w)->display.bindings = NULL;
-    }
+	/* ... and get rid of old atom id's! */
+	_XmFlushAtomsForDisplay(XtDisplay(w));
 
-    /* ... and get rid of old atom id's! */
-    _XmFlushAtomsForDisplay(XtDisplay(w));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Destroy(end)\n"));
 }
 
 #if 1
 /*
- * There is almost nothing dto do -- yet.
+ * There is almost nothing to do -- yet.
  */
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
@@ -542,9 +539,10 @@ _XmGetDropSiteManagerObject(XmDisplay xmDisplay)
 {
     XmDropSiteManagerObject dsm = NULL;
 
-    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmDisplay, "%s:_XmGetDropSiteManagerObject(%d) - %s 0x%p\n",
-    	__FILE__, __LINE__,
+#if 0
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmDisplay, "_XmGetDropSiteManagerObject() - %s 0x%p\n",
     	Display_DSM(xmDisplay) ? "Old" : "New", Display_DSM(xmDisplay)));
+#endif
     if (!XmIsDisplay(xmDisplay))
     {
     	_XmWarning((Widget)xmDisplay, "%s:_XmGetDropSiteManagerObject(%d) called without an XmDisplay",
@@ -580,8 +578,9 @@ _XmGetDragProtocolStyle(Widget w)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(w));
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmGetDragProtocolStyle(%d)\n",
-    	__FILE__, __LINE__));
+#if 0
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDragProtocolStyle()\n"));
+#endif
     switch (Display_DragReceiverProtocolStyle(disp))
     {
     case XmDRAG_NONE:
