@@ -1,9 +1,9 @@
 /** 
  *
- * $Id: Frame.c,v 1.2 2004/09/23 21:03:58 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Frame.c,v 1.4 2004/10/16 16:52:03 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2002 LessTif Development Team
+ * Copyright (C) 1995-2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Frame.c,v 1.2 2004/09/23 21:03:58 dannybackx Exp $";
+static const char rcsid[] = "$Id: Frame.c,v 1.4 2004/10/16 16:52:03 dannybackx Exp $";
 
 
 #include <LTconfig.h>
@@ -839,20 +839,17 @@ static void
 constraint_initialize(Widget request, Widget new_w,
 		      ArgList args, Cardinal *num_args)
 {
-#if XmVERSION > 1
     Cardinal i;
-#endif
 
-    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w, "%s:constraint_initialize()\n", __FILE__));
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w, "constraint_initialize(%s)\n",
+			    _LtDebugFrameChildType2String(FrameC_ChildType(new_w))));
 
-#if XmVERSION > 1
     if (num_args)
 	for (i=0; i<*num_args; i++) {
 	    if (strcmp(args[i].name, XmNframeChildType) == 0) {
 		FrameC_ChildType(new_w) = args[i].value;
 	    }
 	}
-#endif
 
     if (FrameC_ChildHSpacing(new_w) == XmINVALID_DIMENSION)
 	FrameC_ChildHSpacing(new_w) = Frame_MarginWidth(XtParent(new_w)) + 10;
@@ -868,7 +865,7 @@ constraint_initialize(Widget request, Widget new_w,
 
 static void constraint_destroy(Widget w)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "%s:constraint_destroy()\n", __FILE__));
+    DEBUGOUT(_LtDebug(__FILE__, w, "constraint_destroy()\n"));
 }
 
 static Boolean
@@ -877,7 +874,6 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
 {
     Boolean redisplay = False;
 
-#if XmVERSION > 1
     Cardinal i;
 
     if (num_args)
@@ -886,7 +882,6 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
 		FrameC_ChildType(new_w) = args[i].value;
 	    }
 	}
-#endif
 
     if (FrameC_ChildType(current) != FrameC_ChildType(new_w) ||
 	FrameC_ChildHAlignment(current) != FrameC_ChildHAlignment(new_w) ||
