@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.8 2005/03/22 14:48:03 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.12 2006/04/19 18:42:22 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.8 2005/03/22 14:48:03 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.12 2006/04/19 18:42:22 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -67,7 +67,7 @@ static void destroy(Widget w);
 
 static void resize(Widget w);
 
-static void expose(Widget w, XEvent *event, Region region);
+static void XmLabelExpose(Widget w, XEvent *event, Region region);
 
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *proposed,
@@ -357,7 +357,7 @@ XmLabelClassRec xmLabelClassRec = {
 	/* visible_interest      */ False,
 	/* destroy               */ destroy,
 	/* resize                */ resize,
-	/* expose                */ expose,
+	/* expose                */ XmLabelExpose,
 	/* set_values            */ set_values,
 	/* set_values_hook       */ NULL,
 	/* set_values_almost     */ XtInheritSetValuesAlmost, /* FIX ME */
@@ -412,12 +412,10 @@ class_part_initialize(WidgetClass widget_class)
     (XmLabelWidgetClass)(widget_class->core_class.superclass);
     XmPrimitiveClassExt ext, *extptr, *sextptr;
 
-    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_part_initialize(%d) - %s -> %s\n",
-		__FILE__, __LINE__,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "XmLabel class_part_initialize - %s -> %s\n",
 		swc->core_class.class_name,
 		widget_class->core_class.class_name));
-    DEBUGOUT(_LtDebug0("MENUT", NULL, "%s:class_part_initialize(%d) - %s -> %s\n",
-		__FILE__, __LINE__,
+    DEBUGOUT(_LtDebug0("MENUT", NULL, "XmLabel class_part_initialize - %s -> %s\n",
 		swc->core_class.class_name,
 		widget_class->core_class.class_name));
     /* Handle label class part inheritance */
@@ -577,10 +575,9 @@ initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
 	DEBUGOUT(_LtDebug(__FILE__, new_w,
-		"%s:initialize(%d) - %i args, font %p\n"
+		"XmLabel initialize - %i args, font %p\n"
 		"\trequest X %5i Y %5i W %5i H %5i\n"
 		"\t  new_w X %5i Y %5i W %5i H %5i\n",
-		__FILE__, __LINE__,
 		*num_args, ((XmLabelWidget)new_w)->label.font,
 		XtX(request), XtY(request),
 		XtWidth(request), XtHeight(request),
@@ -589,13 +586,9 @@ initialize(Widget request, Widget new_w,
 	DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
 	if (Lab_Font(new_w) == NULL || Lab_Font(new_w) == (XmFontList)XmUNSPECIFIED) {
-#if (XmVERSION > 1)
 		/* Use the trait to find a default renderTable */
 		/* FIX ME currently same as 1.2 */
 		Lab_Font(new_w) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
-#else
-		Lab_Font(new_w) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
-#endif
 	}
 
     Lab_SkipCallback(new_w) = False;
@@ -805,11 +798,11 @@ set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num
 	recalc_needed = False;
 
     DEBUGOUT(_LtDebug(__FILE__, new_w,
-		      "%s(%d):set_values: %i args\n"
+		      "XmLabel set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__, *num_args,
+		      *num_args,
 		      XtX(old), XtY(old),
 		      XtWidth(old), XtHeight(old),
 		      XtX(request), XtY(request),
@@ -1054,118 +1047,86 @@ set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num
 }
 
 static void
-expose(Widget w, XEvent *event, Region region)
+XmLabelExpose(Widget w, XEvent *event, Region region)
 {
-    XRectangle cliprect;
-    GC myGC;
-    Pixmap mypm;
+	XRectangle cliprect;
+	GC myGC;
+	Pixmap mypm;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Expose\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Expose geo %dx%d+%d+%d bw %d hlt %d\n",
+				XtX(w), XtY(w), XtWidth(w), XtHeight(w), XtBorderWidth(w),
+				Prim_HighlightThickness(w)));
 
-    /*
-     * I'm becoming paranoid - Danny - see testXm/filesb/test3
-     */
-    if (!XtIsRealized(w))
-    {
-	_XmWarning(w,
-	    "expose called on unrealized widget - this shouldn't happen");
-	return;
-    }
+	/*
+	* I'm becoming paranoid - see testXm/filesb/test3
+	*/
+	if (!XtIsRealized(w)) {
+		_XmWarning(w, "expose called on unrealized widget - this shouldn't happen");
+		return;
+	}
 
-    if (Prim_Highlighted(w))
-    {
-	(*PrimC_BorderHighlight(XtClass(w))) (w);
-    }
-    else
-    {
-	(*PrimC_BorderUnhighlight(XtClass(w))) (w);
-    }
+	if (Prim_Highlighted(w)) {
+		(*PrimC_BorderHighlight(XtClass(w))) (w);
+	} else {
+		(*PrimC_BorderUnhighlight(XtClass(w))) (w);
+	}
 
-#if 0
-    /*
-     * recompute the labels internals... they could be off if resize
-     * hadn't been called after a change (see set_values)
-     */
-#if 0
-    /* rws 8 May 1998
-       This messes up Mozilla's Bookmark menu buttons which are sub-classed
-       from PushB and CascadeB.
-     */
-    resize(w);
-#else
-    xmLabelClassRec.core_class.resize(w);
+	/* use the right GC */
+	if (XtSensitive(w)) {
+		myGC = Lab_NormalGC(w);
+	} else {
+		myGC = Lab_InsensitiveGC(w);
+	}
 
-#endif
-#endif
-    /* use the right GC */
-    if (XtSensitive(w))
-    {
-	myGC = Lab_NormalGC(w);
-    }
-    else
-    {
-	myGC = Lab_InsensitiveGC(w);
-    }
+	/* Draw the accelerator without clipping */
+	if (Lab_AcceleratorText(w)) {
+		DEBUGOUT(_LtDebug(__FILE__, w, "Expose: acctextrect %d %d %dx%d\n",
+			Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
+			Lab_AccTextRect(w).width, Lab_AccTextRect(w).height));
+		_XmStringDraw(XtDisplay(w), XtWindow(w), Lab_Font(w),
+				Lab_AcceleratorText(w), myGC,
+				Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
+				Lab_AccTextRect(w).width,
+				XmALIGNMENT_BEGINNING, Lab_StringDirection(w), NULL);
+	}
 
-    /* Draw the accelerator without clipping */
-    if (Lab_AcceleratorText(w))
-    {
-	DEBUGOUT(_LtDebug(__FILE__, w,
-			  "Expose: acctextrect %d %d %dx%d\n",
-			  Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
-			  Lab_AccTextRect(w).width, Lab_AccTextRect(w).height));
-	_XmStringDraw(XtDisplay(w), XtWindow(w), Lab_Font(w),
-		      Lab_AcceleratorText(w), myGC,
-		      Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
-		      Lab_AccTextRect(w).width,
-		      XmALIGNMENT_BEGINNING, Lab_StringDirection(w), NULL);
-    }
+	/* Set a clip rectangle for the GC - ensure we don't overwrite shadows */
+	/* the rectangle used to include MarginWidth and MarginHeight.  Leaving
+	 * those two out makes Xinvest and Xmcd look better */
+	/*
+	 * However, not accounting for the margin screws up the default button
+	 * rendering; PushButton will fiddle with the margins to keep the label
+	 * from drawing over the extra shadow.  Basically we want to make the
+	 * label draw itself as though it were smaller than it is but we want
+	 * to keep geometry management doing the "right thing" so we can't
+	 * just fiddle with XmNwidth and XmNheight.  The problem will only
+	 * show up if a PushButton is forced to be smaller than it wants to
+	 * be _and_ there is a defaultButton.  Inspection has revealed that
+	 * the (Top|Bottom|Left|Right)Margin's are the ones we want (yes,
+	 * I did count the pixels).
+	 *
+	 * See similar things in LabelG.c.
+	 */
+	cliprect.x = Prim_HighlightThickness(w) + Prim_ShadowThickness(w) + Lab_MarginLeft(w);
+	cliprect.y = Prim_HighlightThickness(w) + Prim_ShadowThickness(w) + Lab_MarginTop(w);
+	cliprect.width  = XtWidth(w)
+		- ((Prim_ShadowThickness(w) + Prim_HighlightThickness(w)) << 1)
+		- Lab_MarginLeft(w) - Lab_MarginRight(w);
+	cliprect.height = XtHeight(w)
+		- ((Prim_ShadowThickness(w) + Prim_HighlightThickness(w)) << 1)
+		- Lab_MarginTop(w) - Lab_MarginBottom(w);
 
-    /* Set a clip rectangle for the GC - ensure we don't overwrite shadows */
-    /* the rectangle used to include MarginWidth and MarginHeight.  Leaving
-     * those two out makes Xinvest and Xmcd look better */
-    /*
-     * However, not accounting for the margin screws up the default button
-     * rendering; PushButton will fiddle with the margins to keep the label
-     * from drawing over the extra shadow.  Basically we want to make the
-     * label draw itself as though it were smaller than it is but we want
-     * to keep geometry management doing the "right thing" so we can't
-     * just fiddle with XmNwidth and XmNheight.  The problem will only
-     * show up if a PushButton is forced to be smaller than it wants to
-     * be _and_ there is a defaultButton.  Inspection has revealed that
-     * the (Top|Bottom|Left|Right)Margin's are the ones we want (yes,
-     * I did count the pixels).
-     *
-     * See similar things in LabelG.c.
-     */
-    cliprect.x = Prim_HighlightThickness(w)
-               + Prim_ShadowThickness(w)
-               + Lab_MarginLeft(w);
-    cliprect.y = Prim_HighlightThickness(w)
-               + Prim_ShadowThickness(w)
-               + Lab_MarginTop(w);
-    cliprect.width  = XtWidth(w)
-	- ((Prim_ShadowThickness(w) + Prim_HighlightThickness(w)) << 1)
-	- Lab_MarginLeft(w) - Lab_MarginRight(w);
-    cliprect.height = XtHeight(w)
-	- ((Prim_ShadowThickness(w) + Prim_HighlightThickness(w)) << 1)
-	- Lab_MarginTop(w) - Lab_MarginBottom(w);
+	DEBUGOUT(_LtDebug(__FILE__, w, "Expose: cliprect %d %d %dx%d\n",
+				cliprect.x, cliprect.y, cliprect.width, cliprect.height));
 
-    DEBUGOUT(_LtDebug(__FILE__, w,
-		      "Expose: cliprect %d %d %dx%d\n",
-		      cliprect.x, cliprect.y,
-		      cliprect.width, cliprect.height));
+	if (Lab_IsText(w)) {		/* LabelString */
+		if (Lab_Mnemonic(w)) {
+			char m[2];
 
-    if (Lab_IsText(w))
-    {				/* LabelString */
-	if (Lab_Mnemonic(w))
-	{
-	    char m[2];
+			m[0] = Lab_Mnemonic(w);
+			m[1] = '\0';
 
-	    m[0] = Lab_Mnemonic(w);
-	    m[1] = '\0';
-
-	    _XmStringDrawMnemonic(XtDisplay(w), XtWindow(w),
+			_XmStringDrawMnemonic(XtDisplay(w), XtWindow(w),
 				  Lab_Font(w), Lab_Label(w), myGC,
 				  Lab_TextRect_x(w),
 				  Lab_TextRect_y(w),
@@ -1174,263 +1135,191 @@ expose(Widget w, XEvent *event, Region region)
 				  Lab_StringDirection(w),
 				  &cliprect,
 				  m, Lab_MnemonicCharset(w));
-	}
-	else
-	{
-	    _XmStringDraw(XtDisplay(w),
-			  XtWindow(w),
-			  Lab_Font(w),
-			  Lab_Label(w),
-			  myGC,
-			  Lab_TextRect_x(w),
-			  Lab_TextRect_y(w),
-			  Lab_TextRect_width(w),
-			  Lab_Alignment(w),
-			  Lab_StringDirection(w),
-			  &cliprect);
-	}
-    }
-    else
-    {
-	/* Copy only the required part of the pixmap
-	 * (faster than sending a clip to the server).
-	 */
-	mypm = XtSensitive(w)
-	    ? Lab_Pixmap(w)
-	    : Lab_PixmapInsensitive(w);
-#if XmVERSION > 1
-	if (mypm == XmUNSPECIFIED_PIXMAP)
-	{
-	    mypm = Lab_Pixmap(w);
-	}
-#endif
-	if (mypm > XmUNSPECIFIED_PIXMAP &&
-	    cliprect.x + cliprect.width > Lab_TextRect_x(w) &&
-	    cliprect.x < Lab_TextRect_x(w) + Lab_TextRect_width(w) &&
-	    cliprect.y + cliprect.height > Lab_TextRect_y(w) &&
-	    cliprect.y < Lab_TextRect_y(w) + Lab_TextRect_height(w))
-	{
-	    if (cliprect.x < Lab_TextRect_x(w))
-	    {
-		cliprect.width -= Lab_TextRect_x(w) - cliprect.x;
-		cliprect.x = Lab_TextRect_x(w);
-	    }
-	    if (cliprect.x + cliprect.width >
-		Lab_TextRect_x(w) + Lab_TextRect_width(w))
-	    {
-		cliprect.width =
-		    (Lab_TextRect_x(w) + Lab_TextRect_width(w)) - cliprect.x;
-	    }
-	    if (cliprect.y < Lab_TextRect_y(w))
-	    {
-		cliprect.height -= Lab_TextRect_y(w) - cliprect.y;
-		cliprect.y = Lab_TextRect_y(w);
-	    }
-	    if (cliprect.y + cliprect.height >
-		Lab_TextRect_y(w) + Lab_TextRect_height(w))
-	    {
-		cliprect.height =
-		    (Lab_TextRect_y(w) + Lab_TextRect_height(w)) - cliprect.y;
-	    }
-#if XmVERSION > 1
-	    {
-		unsigned int tmp, tmpw, tmph;
-		int tmpx, tmpy;
-		int Depth;
-		Window tmpwin;
-
-		/* rws 4 Mar 2000
-		   According to the comments in label/test12, this does not
-		   happen. We should be adding the pixmap to our pixmap
-		   cache, and getting the info from there instead of a
-		   round trip server query.
-		 */
-		/* rws 10 Mar 2000
-		   Apparently a Motif 2 thing.
-		 */
-		/*
-		   eaf 3 Apr 2000 use the cache for this.  Tests indicate
-		   that Motif does this in set_values, but I like waiting
-		   until we actually need the information.
-		 */
-		{
-		  char *name ;
-		  Pixel fg, bg ;
-		  int hotx, hoty ;
-		  u_int wid, hgt ;
-
-		  if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
-		  	&Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt) )
-		  {
-		    /* This pixmap has never been seen before.  Generate
-		     * a unique name and add it to the cache.  The cache
-		     * mechanism will obtain the depth.  Then we can try
-		     * again.
-		     */
-		    char newname[64] ;
-		    sprintf(newname, "--anon pixmap %p-%x",
-		      (void *)XtScreen(w),
-		      (unsigned)mypm) ;
-		    (void) _XmInstallPixmap(mypm, XtScreen(w), newname,
-			  Prim_Foreground(w), XtBackground(w)) ;
-
-		    /* Ok, let's try again. */
-		    if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
-			  &Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt) )
-		    {
-		      /* Still not found?
-		       * Don't panic, ask the server directly.
-		       */
-		      unsigned uDepth;
-		      XGetGeometry(XtDisplayOfObject(w), mypm, &tmpwin,
-				&tmpx, &tmpy, &tmpw, &tmph, &tmp, &uDepth);
-		      Depth=uDepth;
-		    }
-		  }
+		} else {
+			_XmStringDraw(XtDisplay(w), XtWindow(w),
+					Lab_Font(w), Lab_Label(w), myGC,
+					Lab_TextRect_x(w), Lab_TextRect_y(w),
+					Lab_TextRect_width(w), Lab_Alignment(w),
+					Lab_StringDirection(w), &cliprect);
 		}
+	} else {
+		/* Copy only the required part of the pixmap
+		* (faster than sending a clip to the server).
+		*/
+		mypm = XtSensitive(w) ? Lab_Pixmap(w) : Lab_PixmapInsensitive(w);
+		if (mypm == XmUNSPECIFIED_PIXMAP) {
+			mypm = Lab_Pixmap(w);
+		}
+		if (mypm > XmUNSPECIFIED_PIXMAP &&
+				cliprect.x + cliprect.width > Lab_TextRect_x(w) &&
+				cliprect.x < Lab_TextRect_x(w) + Lab_TextRect_width(w) &&
+				cliprect.y + cliprect.height > Lab_TextRect_y(w) &&
+				cliprect.y < Lab_TextRect_y(w) + Lab_TextRect_height(w))
+		{
+			unsigned int tmp, tmpw, tmph;
+			int tmpx, tmpy;
+			int Depth;
+			Window tmpwin;
+			char *name ;
+			Pixel fg, bg ;
+			int hotx, hoty ;
+			u_int wid, hgt ;
 
-		if (Depth == 1)
-		{
-		    XCopyPlane(XtDisplay(w),
-			  mypm,
-			  XtWindow(w),
-			  myGC,
-			  cliprect.x - Lab_TextRect_x(w),
-			  cliprect.y - Lab_TextRect_y(w),
-			  cliprect.width, cliprect.height,
-			  cliprect.x, cliprect.y,
-			  1);
+			if (cliprect.x < Lab_TextRect_x(w)) {
+				cliprect.width -= Lab_TextRect_x(w) - cliprect.x;
+				cliprect.x = Lab_TextRect_x(w);
+			}
+			if (cliprect.x + cliprect.width > Lab_TextRect_x(w) + Lab_TextRect_width(w))
+			{
+				cliprect.width = (Lab_TextRect_x(w) + Lab_TextRect_width(w))
+					- cliprect.x;
+			}
+			if (cliprect.y < Lab_TextRect_y(w)) {
+				cliprect.height -= Lab_TextRect_y(w) - cliprect.y;
+				cliprect.y = Lab_TextRect_y(w);
+			}
+			if (cliprect.y + cliprect.height >
+					Lab_TextRect_y(w) + Lab_TextRect_height(w)) {
+				cliprect.height = (Lab_TextRect_y(w) + Lab_TextRect_height(w)) - cliprect.y;
+			}
+
+			/* rws 4 Mar 2000
+			 * According to the comments in label/test12, this does not
+			 * happen. We should be adding the pixmap to our pixmap
+			 * cache, and getting the info from there instead of a
+			 * round trip server query.
+			 */
+			/* rws 10 Mar 2000
+			 * Apparently a Motif 2 thing.
+			 */
+			/*
+			 * eaf 3 Apr 2000 use the cache for this.  Tests indicate
+			 * that Motif does this in set_values, but I like waiting
+			 * until we actually need the information.
+			 */
+			if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
+						&Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt)) {
+				/*
+				 * This pixmap has never been seen before.
+				 * Generate a unique name and add it to the cache.
+				 * The cache mechanism will obtain the depth.
+				 * Then we can try again.
+				 */
+				char newname[64] ;
+				sprintf(newname, "--anon pixmap %p-%x",
+					(void *)XtScreen(w), (unsigned)mypm) ;
+				(void) _XmInstallPixmap(mypm, XtScreen(w), newname,
+							Prim_Foreground(w), XtBackground(w)) ;
+
+				/* Ok, let's try again. */
+				if( !_XmGetPixmapData(XtScreen(w), mypm, &name,
+						&Depth, &fg, &bg, &hotx, &hoty, &wid, &hgt)) {
+					/* Still not found?
+					 * Don't panic, ask the server directly.
+					 */
+					unsigned uDepth;
+					XGetGeometry(XtDisplayOfObject(w), mypm, &tmpwin,
+						&tmpx, &tmpy, &tmpw, &tmph, &tmp, &uDepth);
+					Depth=uDepth;
+				}
+			}
+
+			if (Depth == 1) {
+				XCopyPlane(XtDisplay(w), mypm, XtWindow(w), myGC,
+						cliprect.x - Lab_TextRect_x(w),
+						cliprect.y - Lab_TextRect_y(w),
+						cliprect.width, cliprect.height,
+						cliprect.x, cliprect.y, 1);
+			} else if (Depth > 1) {
+				XCopyArea(XtDisplay(w), mypm, XtWindow(w), myGC,
+						cliprect.x - Lab_TextRect_x(w),
+						cliprect.y - Lab_TextRect_y(w),
+						cliprect.width, cliprect.height,
+						cliprect.x, cliprect.y);
+			}
+
+			if (!XtSensitive(w) && Lab_PixmapInsensitive(w) == XmUNSPECIFIED_PIXMAP) {
+				/* label/test14 */
+				XFillRectangle(XtDisplay(w), XtWindow(w), myGC,
+					cliprect.x, cliprect.y, cliprect.width, cliprect.height);
+			}
 		}
-		else if (Depth > 1)
-		{
-		    XCopyArea(XtDisplay(w),
-			  mypm,
-			  XtWindow(w),
-			  myGC,
-			  cliprect.x - Lab_TextRect_x(w),
-			  cliprect.y - Lab_TextRect_y(w),
-			  cliprect.width, cliprect.height,
-			  cliprect.x, cliprect.y);
-		}
-	    }
-	    if (!XtSensitive(w) && Lab_PixmapInsensitive(w) == XmUNSPECIFIED_PIXMAP)
-	    {
-	    	/* label/test14 */
-	    	XFillRectangle(XtDisplay(w), XtWindow(w),
-	    		myGC,
-		  cliprect.x,
-		  cliprect.y,
-		  cliprect.width, cliprect.height);
-	    }
-#else
-	    XCopyArea(XtDisplay(w),
-		  mypm,
-		  XtWindow(w),
-		  myGC,
-		  cliprect.x - Lab_TextRect_x(w),
-		  cliprect.y - Lab_TextRect_y(w),
-		  cliprect.width, cliprect.height,
-		  cliprect.x, cliprect.y);
-#endif
 	}
-    }
 }
 
 static void
 resize(Widget w)
 {
-    if (!XmIsLabel(w))
-    {
-	_XmWarning(w,
-	    "Label resize called on non-Label widget - this shouldn't happen");
-	return;
-    }
-
-    /* Make sure there's room for the accelerator */
-    if (Lab_AcceleratorText(w))
-    {
-	if (Lab_StringDirection(w) == XmSTRING_DIRECTION_L_TO_R)
-	{
-	    if (Lab_MarginRight(w) < LABEL_ACC_PAD + Lab_AccTextRect(w).width)
-		Lab_MarginRight(w) = LABEL_ACC_PAD + Lab_AccTextRect(w).width;
+	if (!XmIsLabel(w)) {
+		_XmWarning(w, "Label resize called on non-Label widget - this shouldn't happen");
+		return;
 	}
-	else
-	{
-	    if (Lab_MarginLeft(w) < LABEL_ACC_PAD + Lab_AccTextRect(w).width)
-		Lab_MarginLeft(w) = LABEL_ACC_PAD + Lab_AccTextRect(w).width;
+
+	/* Make sure there's room for the accelerator */
+	if (Lab_AcceleratorText(w)) {
+		if (Lab_StringDirection(w) == XmSTRING_DIRECTION_L_TO_R) {
+			if (Lab_MarginRight(w) < LABEL_ACC_PAD + Lab_AccTextRect(w).width)
+				Lab_MarginRight(w) = LABEL_ACC_PAD + Lab_AccTextRect(w).width;
+		} else {
+			if (Lab_MarginLeft(w) < LABEL_ACC_PAD + Lab_AccTextRect(w).width)
+				Lab_MarginLeft(w) = LABEL_ACC_PAD + Lab_AccTextRect(w).width;
+		}
 	}
-    }
-    /* Set our preferred dimensions if they are currently zero */
-    if (!XtWidth(w))
-	preferred_size(w, &XtWidth(w), NULL);
-    if (!XtHeight(w))
-	preferred_size(w, NULL, &XtHeight(w));
 
-    /* An RtoL stringDirection reverses the effect of alignment here */
-    switch (Lab_Alignment(w) ^ (Lab_StringDirection(w) << 1))
-    {
-    case XmALIGNMENT_BEGINNING:
-	Lab_TextRect_x(w) = (Lab_Highlight(w)
-			     + Lab_Shadow(w)
-			     + Lab_MarginWidth(w)
-			     + Lab_MarginLeft(w));
-	break;
+	/* Set our preferred dimensions if they are currently zero */
+	if (!XtWidth(w))
+		preferred_size(w, &XtWidth(w), NULL);
+	if (!XtHeight(w))
+		preferred_size(w, NULL, &XtHeight(w));
 
-    case XmALIGNMENT_CENTER:
-    default:
-	Lab_TextRect_x(w) = ((XtWidth(w)
-			      - Lab_MarginLeft(w)
-			      - Lab_MarginRight(w)
-			      - Lab_TextRect_width(w)) >> 1)
-	    + Lab_MarginLeft(w);
-	break;
+	/* An RtoL stringDirection reverses the effect of alignment here */
+	switch (Lab_Alignment(w) ^ (Lab_StringDirection(w) << 1)) {
+	case XmALIGNMENT_BEGINNING:
+		Lab_TextRect_x(w) = (Lab_Highlight(w) + Lab_Shadow(w)
+				+ Lab_MarginWidth(w) + Lab_MarginLeft(w));
+		break;
 
-    case XmALIGNMENT_END:
-	Lab_TextRect_x(w) = (XtWidth(w)
-			     - Lab_Highlight(w)
-			     - Lab_Shadow(w)
-			     - Lab_MarginWidth(w)
-			     - Lab_MarginRight(w)
-			     - Lab_TextRect_width(w));
-	break;
-    }
+	case XmALIGNMENT_CENTER:
+	default:
+		Lab_TextRect_x(w) = ((XtWidth(w) - Lab_MarginLeft(w) - Lab_MarginRight(w)
+					- Lab_TextRect_width(w)) >> 1) + Lab_MarginLeft(w);
+		break;
 
-    Lab_TextRect_y(w) = ((XtHeight(w)
-			  - Lab_MarginTop(w)
-			  - Lab_MarginBottom(w)
-			  - Lab_TextRect_height(w)) >> 1)
-	+ Lab_MarginTop(w);
+	case XmALIGNMENT_END:
+		Lab_TextRect_x(w) = (XtWidth(w) - Lab_Highlight(w) - Lab_Shadow(w)
+				- Lab_MarginWidth(w) - Lab_MarginRight(w) - Lab_TextRect_width(w));
+		break;
+	}
 
-    if (Lab_AcceleratorText(w))
-    {
-	Lab_AccTextRect(w).x =
-	    Lab_StringDirection(w) == XmSTRING_DIRECTION_L_TO_R
-	    ? (XtWidth(w)
-	       - Lab_Highlight(w)
-	       - Lab_Shadow(w)
-	       - Lab_MarginWidth(w)
-	       - Lab_MarginRight(w)
-	       + LABEL_ACC_PAD)
-	    : (Lab_Highlight(w)
-	       + Lab_Shadow(w)
-	       + Lab_MarginWidth(w)
-	       + Lab_MarginLeft(w)
-	       - LABEL_ACC_PAD
-	       - Lab_AccTextRect(w).width);
+	Lab_TextRect_y(w) = ((XtHeight(w) - Lab_MarginTop(w) - Lab_MarginBottom(w)
+				- Lab_TextRect_height(w)) >> 1) + Lab_MarginTop(w);
 
-	Lab_AccTextRect(w).y = ((XtHeight(w)
-				 - Lab_MarginTop(w)
-				 - Lab_MarginBottom(w)
-				 - Lab_AccTextRect(w).height) >> 1)
-	    + Lab_MarginTop(w);
+	if (Lab_AcceleratorText(w)) {
+		Lab_AccTextRect(w).x = Lab_StringDirection(w) == XmSTRING_DIRECTION_L_TO_R
+			? (XtWidth(w) - Lab_Highlight(w) - Lab_Shadow(w)
+					- Lab_MarginWidth(w) - Lab_MarginRight(w) + LABEL_ACC_PAD)
+			: (Lab_Highlight(w) + Lab_Shadow(w) + Lab_MarginWidth(w)
+					+ Lab_MarginLeft(w) - LABEL_ACC_PAD
+					- Lab_AccTextRect(w).width);
+
+		Lab_AccTextRect(w).y = ((XtHeight(w) - Lab_MarginTop(w) - Lab_MarginBottom(w)
+					- Lab_AccTextRect(w).height) >> 1) + Lab_MarginTop(w);
 #if 0
-	DEBUGOUT(_LtDebug(__FILE__, w,
-			  "Accelerator @ %d %d (x = %d - %d - %d - %d)\n",
-			  Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
-			  XtWidth(w), Lab_Shadow(w), Lab_Highlight(w),
-			  Lab_AccTextRect(w).width));
+		DEBUGOUT(_LtDebug(__FILE__, w, "Accelerator @ %d %d (x = %d - %d - %d - %d)\n",
+			Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
+			XtWidth(w), Lab_Shadow(w), Lab_Highlight(w),
+			Lab_AccTextRect(w).width));
 #endif
-    }
+	}
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabel Resize -> tr %dx%d+%d+%d acc %dx%d+%d+%d\n",
+		Lab_TextRect_height(w),
+		Lab_TextRect_width(w),
+		Lab_TextRect_x(w),
+		Lab_TextRect_y(w),
+		Lab_AccTextRect(w).height,
+		Lab_AccTextRect(w).width,
+		Lab_AccTextRect(w).x,
+		Lab_AccTextRect(w).y));
 }
 
 static XtGeometryResult
@@ -1714,7 +1603,7 @@ drag_convert_proc(Widget w, Atom *selection,
 	    }
 	    else{
 	    	buf = XtMalloc(prop.nitems + 1);
-		strncpy(buf, prop.value, prop.nitems);
+		strncpy(buf, (char*)prop.value, prop.nitems);
 		buf[prop.nitems] = '\0';
 	    	*length_return = prop.nitems;
 	    	*value_return  = buf;
@@ -1821,63 +1710,57 @@ _XmLabelGetPixmapSize(Widget w, Pixmap Pix,
 void
 _XmCalcLabelDimensions(Widget w)
 {
-    _XmObjectLock(w);
+	_XmObjectLock(w);
 
-    if (Lab_IsText(w))
-    {
-#if (XmVERSION > 1)
-	__XmRenderTableFinalise(w, Lab_Font(w), Lab_Label(w));
-#endif
-	_XmStringExtent(Lab_Font(w), Lab_Label(w), &Lab_TextRect_width(w),
-			&Lab_TextRect_height(w));
-	if (!Lab_TextRect_width(w))
-	{
-	    /* This used to be in _XmStringExtent, but fits better here: */
-	    /*
-	     * MLM: I know I added this for a reason, but I can't remember why
-	     * right now.
-	     * Now I do.  It's because of nedit.  The height of a menu item is
-	     * is set to 0 (well, really 1); however, without this code,
-	     * XmCalcLabelDimensions returns a different value, even though
-	     * the true height of the label is 0.  Do not comment this code
-	     * (if part).
-	     */
+	if (Lab_IsText(w)) {
+		__XmRenderTableFinalise(w, Lab_Font(w), Lab_Label(w));
+		_XmStringExtent(Lab_Font(w), Lab_Label(w), &Lab_TextRect_width(w),
+				&Lab_TextRect_height(w));
+		if (!Lab_TextRect_width(w)) {
+			/* This used to be in _XmStringExtent, but fits better here: */
+			/*
+			 * I added this because of nedit.  The height of a menu item is
+			 * is set to 0 (well, really 1); however, without this code,
+			 * XmCalcLabelDimensions returns a different value, even though
+			 * the true height of the label is 0.  Do not comment this code
+			 * (if part).
+			 */
+			Lab_TextRect_height(w) = 0;
+		}
+	} else {
+		Pixmap mypm;
 
-	    Lab_TextRect_height(w) = 0;
+		mypm = XtIsSensitive(w) ? Lab_Pixmap(w) : Lab_PixmapInsensitive(w);
+		if (mypm == XmUNSPECIFIED_PIXMAP) {
+			mypm = Lab_Pixmap(w);
+		}
+
+		_XmLabelGetPixmapSize(w, mypm, &Lab_TextRect_width(w), &Lab_TextRect_height(w));
 	}
-    }
-    else
-    {
-    Pixmap mypm;
 
-	mypm = XtIsSensitive(w) ? Lab_Pixmap(w) : Lab_PixmapInsensitive(w);
-#if XmVERSION > 1
-	if (mypm == XmUNSPECIFIED_PIXMAP)
-	{
-	    mypm = Lab_Pixmap(w);
+	if (Lab_AcceleratorText(w)) {
+		_XmStringExtent(Lab_Font(w), Lab_AcceleratorText(w),
+				&Lab_AccTextRect(w).width, &Lab_AccTextRect(w).height);
+		if (!Lab_AccTextRect(w).width) {
+			Lab_AccTextRect(w).height = 0;
+		}
+	} else {
+		Lab_AccTextRect(w).height = 0;
+		Lab_AccTextRect(w).width = 0;
+		Lab_AccTextRect(w).x = 0;
+		Lab_AccTextRect(w).y = 0;
 	}
-#endif
+	_XmObjectUnlock(w);
 
-	_XmLabelGetPixmapSize(w, mypm,
-			      &Lab_TextRect_width(w),
-			      &Lab_TextRect_height(w));
-    }
-
-    if (Lab_AcceleratorText(w)) {
-	_XmStringExtent(Lab_Font(w), Lab_AcceleratorText(w),
-			&Lab_AccTextRect(w).width,
-			&Lab_AccTextRect(w).height);
-	if (!Lab_AccTextRect(w).width)
-	{
-	    Lab_AccTextRect(w).height = 0;
-	}
-    } else {
-	    Lab_AccTextRect(w).height = 0;
-	    Lab_AccTextRect(w).width = 0;
-	    Lab_AccTextRect(w).x = 0;
-	    Lab_AccTextRect(w).y = 0;
-    }
-    _XmObjectUnlock(w);
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmCalcLabelDimensions -> tr %dx%d+%d+%d acc %dx%d+%d+%d\n",
+		Lab_TextRect_height(w),
+		Lab_TextRect_width(w),
+		Lab_TextRect_x(w),
+		Lab_TextRect_y(w),
+		Lab_AccTextRect(w).height,
+		Lab_AccTextRect(w).width,
+		Lab_AccTextRect(w).x,
+		Lab_AccTextRect(w).y));
 }
 
 Widget
