@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MapEvent.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MapEvent.c,v 1.2 2004/10/27 19:31:15 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MapEvent.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MapEvent.c,v 1.2 2004/10/27 19:31:15 dannybackx Exp $";
 
 /*
  * this code borrows heavily from TMparse.c.  The copyright there is as follows:
@@ -389,6 +389,9 @@ FreeEventSeq(EventSeqPtr eventSeq)
     while (evs != NULL)
     {
         EventPtr event = evs;
+	if (event->event.lateModifiers) {
+		XtFree((char *)event->event.lateModifiers);
+	}
 
         evs = evs->next;
 
@@ -2036,7 +2039,6 @@ _XmMapKeyEvent(String str, int *eventType,
 }
 
 
-#if (XmVERSION > 1)
 /*
  * This function is documented in http://motifdeveloper.com/tips/tip15.html
  */
@@ -2095,8 +2097,6 @@ _XmMapKeyEvents(String str, int **eventType, KeySym **keysym, Modifiers **modifi
 	FreeEventSeq(evs);
 	return i;
 }
-#endif /* (XmVERSION > 1) */
-
 
 Boolean
 _XmMatchBtnEvent(XEvent *event, int eventType,
