@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Primitive.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $
+ * $Id: Primitive.c,v 1.4 2005/06/25 09:45:49 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Primitive.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $";
+static const char rcsid[] = "$Id: Primitive.c,v 1.4 2005/06/25 09:45:49 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -36,11 +36,11 @@ static const char rcsid[] = "$Id: Primitive.c,v 1.1 2004/08/28 19:22:45 dannybac
 #include <Xm/ManagerP.h>
 #include <Xm/TransltnsP.h>
 #include <Xm/VirtKeysP.h>
-#if XmVERSION > 1
+
 /* Includes for 2.0 features */
 #include <XmI/DirectionI.h>
 #include <Xm/CareVisualT.h>
-#endif
+
 
 #include <XmI/DebugUtil.h>
 
@@ -50,10 +50,10 @@ static void class_initialize(void);
 static void class_part_initialize(WidgetClass w_class);
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-static void realize(Widget w, XtValueMask *value_mask,
+static void XmPrimitiveRealize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
 static void destroy(Widget w);
-static Boolean set_values(Widget current, Widget request, Widget new_w,
+static Boolean XmPrimitiveSetValues(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 static void focus_change(Widget w, XmFocusChange fevent);
 static XmNavigability widget_navigable(Widget w);
@@ -178,8 +178,6 @@ static XtResource resources[] =
 	sizeof(XtPointer), Offset(user_data),
 	XmRImmediate, (XtPointer)NULL
     }
-
-#if XmVERSION > 1
     ,{
 	XmNconvertCallback, XmCCallback, XmRCallback,
 	sizeof(XtCallbackList), Offset(convert_callback),
@@ -195,8 +193,6 @@ static XtResource resources[] =
 	sizeof(XmDirection), Offset(layout_direction),
 	XmRCallProc, (XtPointer)_XmDirectionDefault
     }
-#endif
-
 };
 
 #define POffset(field)	XtOffset(XmPrimitiveWidget, primitive.field)
@@ -319,7 +315,7 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
 	/* class_inited          */ False,
 	/* initialize            */ initialize,
 	/* initialize_hook       */ NULL,
-	/* realize               */ realize,
+	/* realize               */ XmPrimitiveRealize,
 	/* actions               */ actions,
 	/* num_actions           */ XtNumber(actions),
 	/* resources             */ resources,
@@ -332,7 +328,7 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
 	/* destroy               */ destroy,
 	/* resize                */ NULL,
 	/* expose                */ NULL,
-	/* set_values            */ set_values,
+	/* set_values            */ XmPrimitiveSetValues,
 	/* set_values_hook       */ NULL,
 	/* set_values_almost     */ XtInheritSetValuesAlmost,
 	/* get_values_hook       */ _XmPrimitiveGetValuesHook,
@@ -358,7 +354,6 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
 
 WidgetClass xmPrimitiveWidgetClass = (WidgetClass)&xmPrimitiveClassRec;
 
-#if XmVERSION > 1
 /* Trait record */
 static Boolean _PrimitiveTrait_Redraw(Widget, Widget, Widget, Mask);
 
@@ -366,7 +361,6 @@ static XmCareVisualTraitRec _XmPrimitiveTraitRec = {
 	/* version */		0,
 	/* redraw */		_PrimitiveTrait_Redraw
 };
-#endif
 
 static void
 class_initialize(void)
@@ -376,12 +370,10 @@ class_initialize(void)
 	_XmInitializeExtensions();
 	_XmPrimitiveCoreClassExtRec.record_type = XmQmotif;
 
-#if XmVERSION > 1
 	if (! XmeTraitSet((XtPointer)xmPrimitiveWidgetClass, XmQTcareParentVisual,
 			(XtPointer)&_XmPrimitiveTraitRec)) {
 		_XmWarning(NULL, "XmPrimitive ClassInitialize: XmeTraitSet failed\n");
 	}
-#endif
 }
 
 static void
@@ -651,14 +643,14 @@ destroy(Widget w)
 }
 
 static void
-realize(Widget w,
+XmPrimitiveRealize(Widget w,
 	XtValueMask *value_mask,
 	XSetWindowAttributes *attributes)
 {
     int i;
 
     DEBUGOUT(_LtDebug(__FILE__, w,
-		      "Realize wid before create %d ht %d bw %d\n",
+		      "XmPrimitive Realize wid before create %d ht %d bw %d\n",
 		      XtWidth(w), XtHeight(w), XtBorderWidth(w)));
 
     /*
@@ -688,12 +680,12 @@ realize(Widget w,
 	XtRealizeWidget(w->core.popup_list[i]);
     }
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "Realize wid %d ht %d bw %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmPrimitive Realize wid %d ht %d bw %d\n",
 		      XtWidth(w), XtHeight(w), XtBorderWidth(w)));
 }
 
 static Boolean
-set_values(Widget old, Widget request, Widget new_w,
+XmPrimitiveSetValues(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
     Boolean need_refresh;
@@ -895,61 +887,55 @@ widget_navigable(Widget w)
 static void
 primitive_border_unhighlight(Widget w)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderUnhighlight\n"));
+	if (!XtIsRealized(w)) {
+		DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderUnhighlight\n"));
+		return;
+	}
 
-    if (!XtIsRealized(w))
-    {
-	return;
-    }
+	/* with zero width, we don't need this... */
+	if (Prim_HighlightThickness(w) == 0) {
+		DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderUnhighlight\n"));
+		return;
+	}
 
-    /* with zero width, we don't need this... */
-    if (Prim_HighlightThickness(w) == 0)
-    {
-	return;
-    }
+	if (XmIsManager(XtParent(w))) {
+		DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderUnhighlight xmmgr\n"));
+		_XmDrawSimpleHighlight(XtDisplay(w), XtWindow(w), XmParentBackgroundGC(w),
+				0, 0, XtWidth(w), XtHeight(w),
+				Prim_HighlightThickness(w));
+	} else {
+		DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderUnhighlight no xmmgr\n"));
+		_XmClearBorder(XtDisplay(w), XtWindow(w),
+				0, 0, XtWidth(w), XtHeight(w),
+				Prim_HighlightThickness(w));
+	}
 
-    if (XmIsManager(XtParent(w)))
-    {
-	_XmDrawSimpleHighlight(XtDisplay(w), XtWindow(w),
-			       XmParentBackgroundGC(w),
-			       0, 0, XtWidth(w), XtHeight(w),
-			       Prim_HighlightThickness(w));
-    }
-    else
-    {
-	_XmClearBorder(XtDisplay(w),
-		       XtWindow(w),
-		       0, 0,
-		       XtWidth(w), XtHeight(w),
-		       Prim_HighlightThickness(w));
-    }
-
-    Prim_Highlighted(w) = False;
-    Prim_HighlightDrawn(w) = False;
+	Prim_Highlighted(w) = False;
+	Prim_HighlightDrawn(w) = False;
 }
 
 static void
 primitive_border_highlight(Widget w)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderHighlight\n"));
+	if (!XtIsRealized(w)) {
+		DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderHighlight not realized\n"));
+		return;
+	}
 
-    if (!XtIsRealized(w))
-    {
-	return;
-    }
+	/* with zero width, we don't need this... */
+	if (Prim_HighlightThickness(w) == 0) {
+		DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderHighlight 0 highlight thickness\n"));
+		return;
+	}
 
-    /* with zero width, we don't need this... */
-    if (Prim_HighlightThickness(w) == 0)
-    {
-	return;
-    }
+	DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderHighlight wid %d ht %d hl th %d\n",
+				XtWidth(w), XtHeight(w), Prim_HighlightThickness(w)));
+	_XmDrawSimpleHighlight(XtDisplay(w), XtWindow(w), Prim_HighlightGC(w),
+			0, 0, XtWidth(w), XtHeight(w),
+			Prim_HighlightThickness(w));
 
-    _XmDrawSimpleHighlight(XtDisplay(w), XtWindow(w), Prim_HighlightGC(w),
-			   0, 0, XtWidth(w), XtHeight(w),
-			   Prim_HighlightThickness(w));
-
-    Prim_Highlighted(w) = True;
-    Prim_HighlightDrawn(w) = True;
+	Prim_Highlighted(w) = True;
+	Prim_HighlightDrawn(w) = True;
 }
 
 /* ACTION PROCS */
@@ -1534,7 +1520,6 @@ _XmPrimitiveExportY(Widget widget, int offset, XtArgVal *value)
 	*value = converted_value;
 }
 
-#if XmVERSION > 1
 /*
  * Motif widgets that depend on their parent's appearance are alerted of an appearance
  * change in the parent by the XmQTcareParentVisual trait.
@@ -1588,4 +1573,3 @@ _PrimitiveTrait_Redraw(Widget child, Widget newp, Widget curp, Mask flag)
 		return r;
 	}
 }
-#endif
