@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.42 2003/09/18 15:42:08 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/SpinBox.c,v 1.3 2005/08/15 19:12:32 dannybackx Exp $
  *
  * Copyright (C) 1997, 1998 Free Software Foundation, Inc.
  * Copyright  1998, 1999, 2000, 2001, 2003 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.42 2003/09/18 15:42:08 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/SpinBox.c,v 1.3 2005/08/15 19:12:32 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -120,7 +120,7 @@ static XtResource resources[] =
 	XmRImmediate, (XtPointer)XmARROWS_VERTICAL
     },
     {
-	XmNarrowSize, XmCArrowSize, XmRArrowSize,
+	XmNarrowSize, XmCArrowSize, XmRHorizontalDimension,
 	sizeof(Dimension), Offset(arrow_size),
 	XmRImmediate, (XtPointer)16
     },
@@ -277,6 +277,13 @@ char _XmSpinBox_defaultTranslations[] =
     ":<Key>osfRight:		SpinBRight()\n"
     ":<Key>osfBeginData:	SpinBFirst()\n"
     ":<Key>osfEndData:		SpinBLast()\n"
+#if 1
+    /* Scroll wheel */
+    "<Btn5Down>:	SpinBPrior()\n"
+    "<Btn5Up>:		SpinBDisarm()\n"
+    "<Btn4Down>:	SpinBNext()\n"
+    "<Btn4Up>:		SpinBDisarm()\n"
+#endif
 ;
 
 /* FIX ME - this should go in other files */
