@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ToggleB.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/ToggleB.c,v 1.2 2004/10/20 19:32:11 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleB.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $";
+static const char rcsid[] = "$Id: ToggleB.c,v 1.2 2004/10/20 19:32:11 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -55,38 +55,21 @@ static const char rcsid[] = "$Id: ToggleB.c,v 1.1 2004/08/28 19:22:45 dannybackx
 #define SQUARE_INDICATOR_ELBOW	10
 #define PIXMAP_INDICATOR_ELBOW	13
 
-#if XmVERSION == 1
-#define DETAIL_SHADOW_THICKNESS(w)	Xm3D_ENHANCE_PIXEL
-#define NEXT_TOGGLE(w)			(!TB_Set(w))
-#else
 #define DETAIL_SHADOW_THICKNESS(w)	TB_DetailShadowThickness(w)
 #define INDICATOR_BOX_MASK		0x03
 #define NEXT_TOGGLE(w)			(TB_ToggleMode(w) == XmTOGGLE_BOOLEAN \
 					 || TB_IndType(w) != XmN_OF_MANY      \
 					 ? !TB_Set(w) : (TB_Set(w) + 1) % 3)
-#endif
 
 /* Forward Declarations */
-
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
-static void initialize(Widget request, Widget new_w,
-		       ArgList args, Cardinal *num_args);
-
-static void initialize_prehook(Widget request, Widget new_w,
-			       ArgList args, Cardinal *num_args);
-
-static void initialize_posthook(Widget request, Widget new_w,
-				ArgList args, Cardinal *num_args);
-
+static void initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args);
+static void initialize_prehook(Widget request, Widget new_w, ArgList args, Cardinal *num_args);
+static void initialize_posthook(Widget request, Widget new_w, ArgList args, Cardinal *num_args);
 static void destroy(Widget w);
-
 static void resize(Widget w);
-
 static void expose(Widget w, XEvent *event, Region region);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 
@@ -139,20 +122,12 @@ static XtResource resources[] =
 	sizeof(Boolean), Offset(set),
 	XmRImmediate, (XtPointer)False
     },
-#if XmVERSION == 1
-    {
-	XmNindicatorOn, XmCIndicatorOn, XmRBoolean,
-	sizeof(Boolean), Offset(ind_on),
-	XtRImmediate, (XtPointer)True
-    },
-#else
-    /* The type changed to an unsigned char in 2.0..oh just lovely. */
     {
+	/* The type changed to an unsigned char in 2.0..oh just lovely. */
 	XmNindicatorOn, XmCIndicatorOn, XmRIndicatorOn,
 	sizeof(unsigned char), Offset(ind_on),
 	XtRImmediate, (XtPointer)True
     },
-#endif
     {
 	XmNfillOnSelect, XmCFillOnSelect, XmRBoolean,
 	sizeof(Boolean), Offset(fill_on_select),
@@ -189,7 +164,6 @@ static XtResource resources[] =
 	XtOffsetOf(XmToggleButtonRec, primitive.highlight_thickness),
 	XmRImmediate, (XtPointer)2
     },
-#if XmVERSION > 1
     /* New for 2.0 : */
     {
 	XmNdetailShadowThickness, XmCDetailShadowThickness,
@@ -214,7 +188,6 @@ static XtResource resources[] =
 	sizeof(Pixel), Offset(unselect_color),
 	XmRCallProc, (XtPointer)_XmUnselectColorDefault
     }
-#endif
 };
 
 static XmSyntheticResource syn_resources[] =
@@ -229,13 +202,11 @@ static XmSyntheticResource syn_resources[] =
 	sizeof(Dimension), Offset(indicator_dim),
 	_XmFromVerticalPixels, _XmToVerticalPixels
     },
-#if XmVERSION > 1
     {
 	XmNdetailShadowThickness,
 	sizeof(Dimension), Offset(detail_shadow_thickness),
 	_XmFromHorizontalPixels, _XmToHorizontalPixels
     }
-#endif
 };
 
 static void Arm(Widget w, XEvent *event,
@@ -417,18 +388,13 @@ CreateSelectGC(Widget w)
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask;
 
-#if XmVERSION > 1
-    if (TB_VisualSet(w) == XmINDETERMINATE)
-    {
+    if (TB_VisualSet(w) == XmINDETERMINATE) {
 	mask |= GCStipple | GCTileStipXOrigin | GCTileStipYOrigin;
 	values.fill_style = FillOpaqueStippled;
 	values.ts_x_origin = values.ts_y_origin = 0;
 	values.stipple =
 	    XmGetPixmapByDepth(XtScreen(w), "50_foreground", 1, 0, 1);
-    }
-    else
-#endif
-    {
+    } else {
 	values.fill_style = FillSolid;
     }
     values.function = GXcopy;
@@ -440,10 +406,8 @@ CreateSelectGC(Widget w)
 
     TB_SelectGC(w) = XtGetGC(w, mask, &values);
 
-#if XmVERSION > 1
     values.foreground = TB_UnselectColor(w);
     TB_UnselectGC(w) = XtGetGC(w, mask, &values);
-#endif
 }
 
 static void
@@ -463,16 +427,13 @@ CreateBackgroundGC(Widget w)
     values.foreground = XtBackground(w);
     values.background = Prim_Foreground(w);
 
-#if XmVERSION > 1
 	values.background = TB_UnselectColor(w);
-#endif
 
     TB_BackgroundGC(w) = XtGetGC(w, mask, &values);
 }
 
 static void
-initialize_prehook(Widget request, Widget new_w,
-		   ArgList args, Cardinal *num_args)
+initialize_prehook(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
     _XmSaveCoreClassTranslations(new_w);
 
@@ -523,38 +484,27 @@ initialize(Widget request, Widget new_w,
 	TB_InsenPixmap(new_w) != XmUNSPECIFIED_PIXMAP)
 	Lab_PixmapInsensitive(new_w) = TB_InsenPixmap(new_w);
 
-#if XmVERSION == 1
-    if (Lab_IsPixmap(new_w) && (XtSensitive(new_w)
-				? TB_OnPixmap(new_w)
-				: TB_InsenPixmap(new_w))
-	!= XmUNSPECIFIED_PIXMAP)
-#else
     if (Lab_IsPixmap(new_w) &&
 	(TB_IndeterminatePixmap(new_w) != XmUNSPECIFIED_PIXMAP ||
 	 ((XtSensitive(new_w)
 	   ? TB_OnPixmap(new_w)
 	   : TB_InsenPixmap(new_w))
 	  != XmUNSPECIFIED_PIXMAP)))
-#endif
     {
 	Dimension width, height;
-#if XmVERSION > 1
 	Dimension iwidth, iheight;
-#endif
 
 	_XmLabelGetPixmapSize(new_w,
 			      (XtSensitive(new_w)
 			       ? TB_OnPixmap(new_w)
 			       : TB_InsenPixmap(new_w)),
 			      &width, &height);
-#if XmVERSION > 1
 	_XmLabelGetPixmapSize(new_w, TB_IndeterminatePixmap(new_w),
 			      &iwidth, &iheight);
 	if (width < iwidth)
 	    width = iwidth;
 	if (height < iheight)
 	    height = iheight;
-#endif
 	if (Lab_TextRect_width(new_w) < width ||
 	    Lab_TextRect_height(new_w) < height)
 	{
@@ -586,11 +536,10 @@ initialize(Widget request, Widget new_w,
     CreateSelectGC(new_w);
     CreateBackgroundGC(new_w);
 
-#if XmVERSION > 1
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRToggleMode),
 			     TB_ToggleMode(new_w), new_w))
 	TB_ToggleMode(new_w) = XmTOGGLE_BOOLEAN;
-#endif
+
     if (TB_IndType(new_w) == (unsigned char)XmUNSPECIFIED ||
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
 			     TB_IndType(new_w), new_w))
@@ -605,13 +554,9 @@ initialize(Widget request, Widget new_w,
 	TB_Visible(new_w) = !IN_MENU(new_w);
 
     if (TB_FillOnSelect(new_w) == UNSPECIFIED_TB_BOOLEAN)
-#if XmVERSION == 1
-	TB_FillOnSelect(new_w) = TB_IndOn(new_w);
-#else
 	TB_FillOnSelect(new_w) = (TB_IndType(new_w) == XmN_OF_MANY
 				  ? TB_IndOn(new_w) & INDICATOR_BOX_MASK
 				  : TB_IndOn(new_w)) != 0;
-#endif
 
     if (TB_IndOn(new_w))
     {
@@ -676,9 +621,7 @@ destroy(Widget w)
 {
     XtReleaseGC(w, TB_SelectGC(w));
     XtReleaseGC(w, TB_BackgroundGC(w));
-#if XmVERSION > 1
     XtReleaseGC(w, TB_UnselectGC(w));
-#endif
 }
 
 static Boolean
@@ -693,12 +636,10 @@ set_values(Widget old, Widget request, Widget new_w,
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
 			     TB_IndType(new_w), new_w))
 	TB_IndType(new_w) = TB_IndType(old);
-#if XmVERSION > 1
     if (TB_ToggleMode(old) != TB_ToggleMode(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRToggleMode),
 			     TB_ToggleMode(new_w), new_w))
 	TB_ToggleMode(new_w) = TB_ToggleMode(old);
-#endif
 
     if (TB_SelectColor(new_w) != TB_SelectColor(old))
     {
@@ -733,9 +674,7 @@ set_values(Widget old, Widget request, Widget new_w,
     }
 
     if (Lab_IsPixmap(new_w) && (Lab_RecomputeSize(new_w) ||
-#if XmVERSION > 1
 	TB_IndeterminatePixmap(new_w) != XmUNSPECIFIED_PIXMAP ||
-#endif
 	(XtSensitive(new_w)
 	 ? Lab_Pixmap(request) != Lab_Pixmap(old) ||
 	   TB_OnPixmap(new_w) != TB_OnPixmap(old)
@@ -743,23 +682,20 @@ set_values(Widget old, Widget request, Widget new_w,
 	   TB_InsenPixmap(new_w) != TB_InsenPixmap(old))))
     {
 	Dimension width, height;
-#if XmVERSION > 1
 	Dimension iwidth, iheight;
-#endif
 
 	_XmLabelGetPixmapSize(new_w,
 			      (XtSensitive(new_w)
 			       ? TB_OnPixmap(new_w)
 			       : TB_InsenPixmap(new_w)),
 			      &width, &height);
-#if XmVERSION > 1
 	_XmLabelGetPixmapSize(new_w, TB_IndeterminatePixmap(new_w),
 			      &iwidth, &iheight);
 	if (width < iwidth)
 	    width = iwidth;
 	if (height < iheight)
 	    height = iheight;
-#endif
+
 	if (Lab_TextRect_width(new_w) < width ||
 	    Lab_TextRect_height(new_w) < height)
 	{
@@ -893,9 +829,7 @@ set_values(Widget old, Widget request, Widget new_w,
     }
 
     if (TB_IndType(new_w) != TB_IndType(old)
-#if XmVERSION > 1
 	|| TB_DetailShadowThickness(new_w) != TB_DetailShadowThickness(old)
-#endif
 	|| ((TB_IndOn(new_w) || TB_IndOn(old))
 	    && (TB_Visible(new_w) != TB_Visible(old)
 		|| TB_FillOnSelect(new_w) != TB_FillOnSelect(old))))
@@ -907,7 +841,6 @@ set_values(Widget old, Widget request, Widget new_w,
     {
 	if (!refresh_needed)
 	    draw_toggle(new_w, NULL, NULL, False, TB_Set(new_w));
-#if XmVERSION > 1
 	else if ((TB_Set(old) == XmINDETERMINATE ||
 		  TB_Set(new_w) == XmINDETERMINATE)
 		 && TB_SelectColor(new_w) == TB_SelectColor(old))
@@ -915,7 +848,6 @@ set_values(Widget old, Widget request, Widget new_w,
 	    XtReleaseGC(new_w, TB_SelectGC(new_w));
 	    CreateSelectGC(new_w);
 	}
-#endif
 	TB_VisualSet(new_w) = TB_Set(new_w);
     }
 
@@ -1380,7 +1312,6 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	/* Called from an action: set visual_set and draw some stuff */
 	if (TB_VisualSet(w) == visual_set)
 	    return;
-#if XmVERSION > 1
 	if (TB_VisualSet(w) == XmINDETERMINATE || visual_set == XmINDETERMINATE)
 	{
 	    /* FIX ME: Change the GC for a toggle?  That's ridiculous!
@@ -1390,10 +1321,7 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	    XtReleaseGC(w, TB_SelectGC(w));
 	    TB_VisualSet(w) = visual_set;
 	    CreateSelectGC(w);
-	}
-	else
-#endif
-	{
+	} else {
 	    TB_VisualSet(w) = visual_set;
 	}
 	if (!XtIsRealized(w))
@@ -1412,12 +1340,8 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
     }
 
     if (is_expose || (!TB_IndOn(w) && TB_FillOnSelect(w)) ||
-	(Lab_IsPixmap(w) && (
-#if XmVERSION > 1
-	 TB_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP ||
-#endif
-	 (XtSensitive(w) ? TB_OnPixmap(w) :
-	  TB_InsenPixmap(w)) != XmUNSPECIFIED_PIXMAP)))
+	(Lab_IsPixmap(w) && ( TB_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP ||
+	 (XtSensitive(w) ? TB_OnPixmap(w) : TB_InsenPixmap(w)) != XmUNSPECIFIED_PIXMAP)))
     {
 	if (Lab_IsPixmap(w))
 	{
@@ -1426,41 +1350,26 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 		/* Switch pixmaps before drawing label */
 		if (XtSensitive(w))
 		{
-#if XmVERSION > 1
 		    if (visual_set == XmINDETERMINATE &&
-			TB_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP)
-		    {
+			TB_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP) {
 			tmp_pix = Lab_Pixmap(w);
 			Lab_Pixmap(w) = TB_IndeterminatePixmap(w);
-		    }
-		    else
-#endif
-		    if (TB_OnPixmap(w) != XmUNSPECIFIED_PIXMAP)
-		    {
+		    } else if (TB_OnPixmap(w) != XmUNSPECIFIED_PIXMAP) {
 			tmp_pix = Lab_Pixmap(w);
 			Lab_Pixmap(w) = TB_OnPixmap(w);
 		    }
-		}
-		else
-		{
-#if XmVERSION > 1
+		} else {
 		    if (visual_set == XmINDETERMINATE &&
-			TB_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP)
-		    {
+			TB_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP) {
 			tmp_pix = Lab_PixmapInsensitive(w);
 			Lab_PixmapInsensitive(w) = TB_IndeterminatePixmap(w);
-		    }
-		    else
-#endif
-		    if (TB_InsenPixmap(w) != XmUNSPECIFIED_PIXMAP)
-		    {
+		    } else if (TB_InsenPixmap(w) != XmUNSPECIFIED_PIXMAP) {
 			tmp_pix = Lab_PixmapInsensitive(w);
 			Lab_PixmapInsensitive(w) = TB_InsenPixmap(w);
 		    }
 		}
 	    }
-	    if (!is_expose && (TB_IndOn(w) || !TB_FillOnSelect(w)))
-	    {
+	    if (!is_expose && (TB_IndOn(w) || !TB_FillOnSelect(w))) {
 		XRectangle cliprect;
 
 		/* Changing pixmaps: erase the TextRect just in case
@@ -1551,19 +1460,12 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	{
 	    /* Non-menu: draw shadows in or out */
 	    _XmDrawShadows(XtDisplay(w), XtWindow(w),
-#if XmVERSION == 1
-			   Prim_TopShadowGC(w), Prim_BottomShadowGC(w),
-#else
-			   visual_set == XmINDETERMINATE
-			    ? Lab_InsensitiveGC(w) : Prim_TopShadowGC(w),
-			   visual_set == XmINDETERMINATE
-			    ? Lab_InsensitiveGC(w) : Prim_BottomShadowGC(w),
-#endif
-			   Lab_Highlight(w), Lab_Highlight(w),
-			   XtWidth(w) - (Lab_Highlight(w) << 1),
-			   XtHeight(w) - (Lab_Highlight(w) << 1),
-			   Lab_Shadow(w), visual_set && !TB_IndOn(w)
-			   ? XmSHADOW_IN : XmSHADOW_OUT);
+		visual_set == XmINDETERMINATE ? Lab_InsensitiveGC(w) : Prim_TopShadowGC(w),
+		visual_set == XmINDETERMINATE ? Lab_InsensitiveGC(w) : Prim_BottomShadowGC(w),
+		Lab_Highlight(w), Lab_Highlight(w),
+		XtWidth(w) - (Lab_Highlight(w) << 1),
+		XtHeight(w) - (Lab_Highlight(w) << 1),
+		Lab_Shadow(w), visual_set && !TB_IndOn(w) ? XmSHADOW_IN : XmSHADOW_OUT);
 	}
     }
 
@@ -1634,14 +1536,9 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	case XmN_OF_MANY:
 	    if (visual_set || TB_Visible(w))
 	    {
-#if XmVERSION > 1
 		if (TB_IndOn(w) & INDICATOR_BOX_MASK)
 		{
-#endif
 		    _XmDrawShadows(XtDisplay(w), XtWindow(w),
-#if XmVERSION == 1
-				   Prim_TopShadowGC(w), Prim_BottomShadowGC(w),
-#else
 				   visual_set == XmINDETERMINATE
 				   ? Lab_InsensitiveGC(w)
 				   : (TB_IndOn(w) & INDICATOR_BOX_MASK)
@@ -1651,17 +1548,14 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 				   visual_set == XmINDETERMINATE
 				   ? Lab_InsensitiveGC(w)
 				   : Prim_BottomShadowGC(w),
-#endif
 				   x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
 				   visual_set ? XmSHADOW_IN : XmSHADOW_OUT);
 		    delta = DETAIL_SHADOW_THICKNESS(w) + (1 - fill);
-#if XmVERSION > 1
 		}
 		else
 		{
 		    delta = 0;
 		}
-#endif
 		if (dim > delta << 1)
 		{
 		    if (is_expose || TB_FillOnSelect(w))
@@ -1672,7 +1566,6 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 				       x + delta, y + delta,
 				       dim - (delta << 1), dim - (delta << 1));
 		    }
-#if XmVERSION > 1
 		DEBUGOUT(_LtDebug(__FILE__, w,
 			"draw_toggle tbion %d ibm %d vs %d ie %d tbfos %d\n",
 			TB_IndOn(w), ~INDICATOR_BOX_MASK,
@@ -1710,9 +1603,6 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 				XFillRectangle(XtDisplay(w), XtWindow(w), TB_UnselectGC(w),
 					x, y, dim, dim);
 				_XmDrawShadows(XtDisplay(w), XtWindow(w),
-#if XmVERSION == 1
-				   Prim_TopShadowGC(w), Prim_BottomShadowGC(w),
-#else
 				   visual_set == XmINDETERMINATE
 				   ? Lab_InsensitiveGC(w)
 				   : (TB_IndOn(w) & INDICATOR_BOX_MASK)
@@ -1722,12 +1612,10 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 				   visual_set == XmINDETERMINATE
 				   ? Lab_InsensitiveGC(w)
 				   : Prim_BottomShadowGC(w),
-#endif
 				   x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
 				   visual_set ? XmSHADOW_IN : XmSHADOW_OUT);
 			}
 		  }
-#endif
 #endif
 		}
 	    }
@@ -1738,7 +1626,6 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	    }
 	    break;
 
-#if XmVERSION > 1
 	case XmONE_OF_MANY_ROUND:
 	    XmeDrawCircle(XtDisplay(w), XtWindow(w),
 		visual_set ? Prim_BottomShadowGC(w) :
@@ -1749,7 +1636,6 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 			? TB_SelectGC(w) : TB_BackgroundGC(w) : NULL,
 		x, y, dim, dim, TB_DetailShadowThickness(w), 1);
 	    break;
-#endif
 
 	default: /* XmONE_OF_MANY[_DIAMOND] */
 	    DEBUGOUT(_LtDebug(__FILE__, w, "Toggle %s\n", visual_set ? "on" : "off"));
@@ -1762,18 +1648,10 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 		(is_expose || TB_FillOnSelect(w))
 			? (visual_set && TB_FillOnSelect(w))
 				? TB_SelectGC(w)
-#if XmVERSION > 1
 				: TB_UnselectGC(w)
-#else
-				: TB_BackgroundGC(w)
-#endif
 			: NULL,
 		x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
-#if XmVERSION == 1
-		fill);
-#else
 		!fill);
-#endif
 	}
     }
 }
@@ -1887,7 +1765,6 @@ _XmUnselectColorDefault(Widget w, int offset, XrmValue *val)
 {
 	DEBUGOUT(_LtDebug(__FILE__, w, "_XmUnselectColorDefault\n"));
 
-#if XmVERSION > 1
 	/*
 	 * XmNunselectColor
 	 * This resource's default for a color display is XmNbackground.
@@ -1903,6 +1780,5 @@ _XmUnselectColorDefault(Widget w, int offset, XrmValue *val)
 	} else {					/* Colour */
 	}
 #endif
-#endif
 }
 
