@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.87 2003/10/06 16:09:10 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/ToggleBG.c,v 1.2 2004/10/21 18:53:59 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.87 2003/10/06 16:09:10 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/ToggleBG.c,v 1.2 2004/10/21 18:53:59 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -57,16 +57,11 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c
 #define SQUARE_INDICATOR_ELBOW	10
 #define PIXMAP_INDICATOR_ELBOW	13
 
-#if XmVERSION == 1
-#define DETAIL_SHADOW_THICKNESS(w)	Xm3D_ENHANCE_PIXEL
-#define NEXT_TOGGLE(w)			(!TBG_Set(w))
-#else
 #define DETAIL_SHADOW_THICKNESS(w)	TBG_DetailShadowThickness(w)
 #define INDICATOR_BOX_MASK		0x03
 #define NEXT_TOGGLE(w)			(TBG_ToggleMode(w) == XmTOGGLE_BOOLEAN\
 					 || TBG_IndType(w) != XmN_OF_MANY     \
 					 ? !TBG_Set(w) : (TBG_Set(w) + 1) % 3)
-#endif
 
 /* Forward Declarations */
 
@@ -179,20 +174,12 @@ static XtResource cache_resources[] =
 	sizeof(Pixmap), Offset(insen_pixmap),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED_PIXMAP
     },
-#if XmVERSION == 1
-    {
-	XmNindicatorOn, XmCIndicatorOn, XmRBoolean,
-	sizeof(Boolean), Offset(ind_on),
-	XmRImmediate, (XtPointer)True
-    },
-#else
-    /* The type changed to an unsigned char in 2.0..oh just lovely. */
     {
+	/* The type changed to an unsigned char in 2.0..oh just lovely. */
 	XmNindicatorOn, XmCIndicatorOn, XmRIndicatorOn,
 	sizeof(unsigned char), Offset(ind_on),
 	XmRImmediate, (XtPointer)True
     },
-#endif
     {
 	XmNfillOnSelect, XmCFillOnSelect, XmRBoolean,
 	sizeof(Boolean), Offset(fill_on_select),
@@ -203,13 +190,11 @@ static XtResource cache_resources[] =
 	sizeof(Pixel), Offset(select_color),
 	XmRCallProc, (XtPointer)_XmSelectColorDefault
     },
-#if XmVERSION > 1
     {
 	XmNunselectColor, XmCUnselectColor, XmRPixel,
 	sizeof(Pixel), Offset(unselect_color),
 	XmRCallProc, (XtPointer)_XmUnselectColorDefault
     }
-#endif
 };
 
 static XmSyntheticResource cache_syn_resources[] =
@@ -314,7 +299,6 @@ static XtResource resources[] = {
 	XtOffsetOf(XmToggleButtonGadgetRec,gadget.highlight_thickness),
 	XmRImmediate, (XtPointer)2
     },
-#if XmVERSION > 1
     /* New for 2.0 : */
     {
 	XmNdetailShadowThickness, XmCDetailShadowThickness,
@@ -343,7 +327,6 @@ static XmSyntheticResource syn_resources[] =
 	sizeof(Dimension), Offset(detail_shadow_thickness),
 	_XmFromHorizontalPixels, _XmToHorizontalPixels
      }
-#endif
 };
 
 static XmBaseClassExtRec _XmToggleBGRectClassExtRec = {
@@ -391,9 +374,7 @@ static XmGadgetClassExtRec _XmToggleBGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ XmInheritBaselineProc,
     /* display_rect_proc         */ XmInheritDisplayRectProc,
-#if XmVERSION >= 2
     /* margins_proc              */ XmInheritMarginsProc,
-#endif
 };
 
 XmToggleButtonGadgetClassRec xmToggleButtonGadgetClassRec = {
@@ -439,11 +420,7 @@ XmToggleButtonGadgetClassRec xmToggleButtonGadgetClassRec = {
 	/* arm_and_activate   */ ArmAndActivate,
 	/* input_dispatch     */ input_dispatch,
 	/* visual_change      */ NULL, /* FIX ME */
-#if XmVERSION == 1
-	/* syn_resources      */ NULL,
-#else
 	/* syn_resources      */ syn_resources,
-#endif
 	/* num_syn_resources  */ 0,
 	/* cache_part         */ &cache_part,
 	/* extension          */ (XtPointer)&_XmToggleBGadgetClassExtRec
@@ -590,7 +567,6 @@ CreateSelectGC(Widget w)
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask;
 
-#if XmVERSION > 1
     if (TBG_VisualSet(w) == XmINDETERMINATE)
     {
 	mask |= GCStipple | GCTileStipXOrigin | GCTileStipYOrigin;
@@ -598,10 +574,7 @@ CreateSelectGC(Widget w)
 	values.ts_x_origin = values.ts_y_origin = 0;
 	values.stipple =
 	    XmGetPixmapByDepth(XtScreen(w), "50_foreground", 1, 0, 1);
-    }
-    else
-#endif
-    {
+    } else {
 	values.fill_style = FillSolid;
     }
     values.function = GXcopy;
@@ -613,14 +586,12 @@ CreateSelectGC(Widget w)
 
     TBG_SelectGC(w) = XtGetGC(w, mask, &values);
 
-#if XmVERSION > 1
     values.foreground = TBG_UnselectColor(w);
 
     DEBUGOUT(_LtDebug(__FILE__, w, "CreateSelectGC: unselect color %p\n",
 	TBG_UnselectColor(w)));
 
     TBG_UnselectGC(w) = XtGetGC(w, mask, &values);
-#endif
 }
 
 static void
@@ -689,38 +660,29 @@ initialize(Widget request, Widget new_w,
 	TBG_InsenPixmap(new_w) != XmUNSPECIFIED_PIXMAP)
 	LabG_PixmapInsensitive(new_w) = TBG_InsenPixmap(new_w);
 
-#if XmVERSION == 1
-    if (LabG_IsPixmap(new_w) && (XtSensitive(new_w)
-				 ? TBG_OnPixmap(new_w)
-				 : TBG_InsenPixmap(new_w))
-	!= XmUNSPECIFIED_PIXMAP)
-#else
     if (LabG_IsPixmap(new_w) &&
 	(TBG_IndeterminatePixmap(new_w) != XmUNSPECIFIED_PIXMAP ||
 	 ((XtSensitive(new_w)
 	   ? TBG_OnPixmap(new_w)
 	   : TBG_InsenPixmap(new_w))
 	  != XmUNSPECIFIED_PIXMAP)))
-#endif
     {
 	Dimension width, height;
-#if XmVERSION > 1
 	Dimension iwidth, iheight;
-#endif
 
 	_XmLabelGetPixmapSize(new_w,
 			      (XtSensitive(new_w)
 			       ? TBG_OnPixmap(new_w)
 			       : TBG_InsenPixmap(new_w)),
 			      &width, &height);
-#if XmVERSION > 1
+
 	_XmLabelGetPixmapSize(new_w, TBG_IndeterminatePixmap(new_w),
 			      &iwidth, &iheight);
 	if (width < iwidth)
 	    width = iwidth;
 	if (height < iheight)
 	    height = iheight;
-#endif
+
 	if (LabG_TextRect_width(new_w) < width ||
 	    LabG_TextRect_height(new_w) < height)
 	{
@@ -752,11 +714,10 @@ initialize(Widget request, Widget new_w,
     CreateSelectGC(new_w);
     CreateBackgroundGC(new_w);
 
-#if XmVERSION > 1
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRToggleMode),
 			     TBG_ToggleMode(new_w), new_w))
 	TBG_ToggleMode(new_w) = XmTOGGLE_BOOLEAN;
-#endif
+
     if (TBG_IndType(new_w) == (unsigned char)XmUNSPECIFIED ||
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
 			     TBG_IndType(new_w), new_w))
@@ -771,13 +732,9 @@ initialize(Widget request, Widget new_w,
 	TBG_Visible(new_w) = !IN_MENU(new_w);
 
     if (TBG_FillOnSelect(new_w) == UNSPECIFIED_TBG_BOOLEAN)
-#if XmVERSION == 1
-	TBG_FillOnSelect(new_w) = TBG_IndOn(new_w);
-#else
-    TBG_FillOnSelect(new_w) = (TBG_IndType(new_w) == XmN_OF_MANY
+	TBG_FillOnSelect(new_w) = (TBG_IndType(new_w) == XmN_OF_MANY
 				   ? TBG_IndOn(new_w) & INDICATOR_BOX_MASK
 				   : TBG_IndOn(new_w)) != 0;
-#endif
 
     if (TBG_IndOn(new_w))
     {
@@ -845,9 +802,7 @@ destroy(Widget w)
 {
     XtReleaseGC(w, TBG_SelectGC(w));
     XtReleaseGC(w, TBG_BackgroundGC(w));
-#if XmVERSION > 1
     XtReleaseGC(w, TBG_UnselectGC(w));
-#endif
 
     _XmCacheDelete((XtPointer)TBG_Cache(w));
 }
@@ -970,12 +925,12 @@ set_values(Widget old, Widget request, Widget new_w,
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
 			     TBG_IndType(new_w), new_w))
 	TBG_IndType(new_w) = TBG_IndType(old);
-#if XmVERSION > 1
+
     if (TBG_ToggleMode(old) != TBG_ToggleMode(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
 			     TBG_ToggleMode(new_w), new_w))
 	TBG_ToggleMode(new_w) = TBG_ToggleMode(old);
-#endif
+
 
     if (TBG_SelectColor(new_w) != TBG_SelectColor(old))
     {
@@ -1014,9 +969,7 @@ set_values(Widget old, Widget request, Widget new_w,
     }
 
     if (LabG_IsPixmap(new_w) && (LabG_RecomputeSize(new_w) ||
-#if XmVERSION > 1
 	TBG_IndeterminatePixmap(new_w) != XmUNSPECIFIED_PIXMAP ||
-#endif
 	(XtSensitive(new_w)
 	 ? LabG_Pixmap(request) != LabG_Pixmap(old) ||
 	   TBG_OnPixmap(new_w) != TBG_OnPixmap(old)
@@ -1024,23 +977,20 @@ set_values(Widget old, Widget request, Widget new_w,
 	   TBG_InsenPixmap(new_w) != TBG_InsenPixmap(old))))
     {
 	Dimension width, height;
-#if XmVERSION > 1
 	Dimension iwidth, iheight;
-#endif
 
 	_XmLabelGetPixmapSize(new_w,
 			      (XtSensitive(new_w)
 			       ? TBG_OnPixmap(new_w)
 			       : TBG_InsenPixmap(new_w)),
 			      &width, &height);
-#if XmVERSION > 1
 	_XmLabelGetPixmapSize(new_w, TBG_IndeterminatePixmap(new_w),
 			      &iwidth, &iheight);
 	if (width < iwidth)
 	    width = iwidth;
 	if (height < iheight)
 	    height = iheight;
-#endif
+
 	if (LabG_TextRect_width(new_w) < width ||
 	    LabG_TextRect_height(new_w) < height)
 	{
@@ -1175,9 +1125,7 @@ set_values(Widget old, Widget request, Widget new_w,
     }
 
     if (TBG_IndType(new_w) != TBG_IndType(old)
-#if XmVERSION > 1
 	|| TBG_DetailShadowThickness(new_w) != TBG_DetailShadowThickness(old)
-#endif
 	|| ((TBG_IndOn(new_w) || TBG_IndOn(old))
 	    && (TBG_Visible(new_w) != TBG_Visible(old)
 		|| TBG_FillOnSelect(new_w) != TBG_FillOnSelect(old))))
@@ -1189,7 +1137,6 @@ set_values(Widget old, Widget request, Widget new_w,
     {
 	if (!refresh_needed)
 	    draw_toggle(new_w, NULL, NULL, False, TBG_Set(new_w));
-#if XmVERSION > 1
 	else if ((TBG_Set(old) == XmINDETERMINATE ||
 		  TBG_Set(new_w) == XmINDETERMINATE)
 		 && TBG_SelectColor(new_w) == TBG_SelectColor(old))
@@ -1197,7 +1144,6 @@ set_values(Widget old, Widget request, Widget new_w,
 	    XtReleaseGC(new_w, TBG_SelectGC(new_w));
 	    CreateSelectGC(new_w);
 	}
-#endif
 	TBG_VisualSet(new_w) = TBG_Set(new_w);
     }
 
@@ -1818,7 +1764,6 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	/* Called from an action: set visual_set and draw some stuff */
 	if (TBG_VisualSet(w) == visual_set)
 	    return;
-#if XmVERSION > 1
 	if (TBG_VisualSet(w) == XmINDETERMINATE ||
 	    visual_set == XmINDETERMINATE)
 	{
@@ -1829,10 +1774,7 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	    XtReleaseGC(w, TBG_SelectGC(w));
 	    TBG_VisualSet(w) = visual_set;
 	    CreateSelectGC(w);
-	}
-	else
-#endif
-	{
+	} else {
 	    TBG_VisualSet(w) = visual_set;
 	}
 	if (!XtIsRealized(w))
@@ -1852,9 +1794,7 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 
     if (is_expose || (!TBG_IndOn(w) && TBG_FillOnSelect(w)) ||
 	(LabG_IsPixmap(w) && (
-#if XmVERSION > 1
 	 TBG_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP ||
-#endif
 	 (XtSensitive(w) ? TBG_OnPixmap(w) :
 	  TBG_InsenPixmap(w)) != XmUNSPECIFIED_PIXMAP)))
     {
@@ -1865,41 +1805,27 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 		/* Switch pixmaps before drawing label */
 		if (XtSensitive(w))
 		{
-#if XmVERSION > 1
 		    if (visual_set == XmINDETERMINATE &&
-			TBG_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP)
-		    {
+			TBG_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP) {
 			tmp_pix = LabG_Pixmap(w);
 			LabG_Pixmap(w) = TBG_IndeterminatePixmap(w);
-		    }
-		    else
-#endif
-		    if (TBG_OnPixmap(w) != XmUNSPECIFIED_PIXMAP)
-		    {
+		    } else if (TBG_OnPixmap(w) != XmUNSPECIFIED_PIXMAP) {
 			tmp_pix = LabG_Pixmap(w);
 			LabG_Pixmap(w) = TBG_OnPixmap(w);
 		    }
-		}
-		else
-		{
-#if XmVERSION > 1
+		} else {
 		    if (visual_set == XmINDETERMINATE &&
-			TBG_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP)
-		    {
+			TBG_IndeterminatePixmap(w) != XmUNSPECIFIED_PIXMAP) {
 			tmp_pix = LabG_Pixmap(w);
 			LabG_Pixmap(w) = TBG_IndeterminatePixmap(w);
-		    }
-		    else
-#endif
-		    if (TBG_InsenPixmap(w) != XmUNSPECIFIED_PIXMAP)
+		    } else if (TBG_InsenPixmap(w) != XmUNSPECIFIED_PIXMAP)
 		    {
 			tmp_pix = LabG_PixmapInsensitive(w);
 			LabG_PixmapInsensitive(w) = TBG_InsenPixmap(w);
 		    }
 		}
 	    }
-	    if (!is_expose && (TBG_IndOn(w) || !TBG_FillOnSelect(w)))
-	    {
+	    if (!is_expose && (TBG_IndOn(w) || !TBG_FillOnSelect(w))) {
 		XRectangle cliprect;
 
 		/* Changing pixmaps: erase the TextRect just in case
@@ -1999,16 +1925,12 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	{
 	    /* Non-menu: draw shadows in or out */
 	    _XmDrawShadows(XtDisplay(w), XtWindow(w),
-#if XmVERSION == 1
-			   XmParentTopShadowGC(w), XmParentBottomShadowGC(w),
-#else
 			   visual_set == XmINDETERMINATE
 			    ? LabG_InsensitiveGC(w)
 			    : XmParentTopShadowGC(w),
 			   visual_set == XmINDETERMINATE
 			    ? LabG_InsensitiveGC(w)
 			    : XmParentBottomShadowGC(w),
-#endif
 			   XtX(w) + LabG_Highlight(w),
 			   XtY(w) + LabG_Highlight(w),
 			   XtWidth(w) - (LabG_Highlight(w) << 1),
@@ -2085,15 +2007,9 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 	case XmN_OF_MANY:
 	    if (visual_set || TBG_Visible(w))
 	    {
-#if XmVERSION > 1
 		if (TBG_IndOn(w) & INDICATOR_BOX_MASK)
 		{
-#endif
 		    _XmDrawShadows(XtDisplay(w), XtWindow(w),
-#if XmVERSION == 1
-				   XmParentTopShadowGC(w),
-				   XmParentBottomShadowGC(w),
-#else
 				   visual_set == XmINDETERMINATE
 				   ? LabG_InsensitiveGC(w)
 				   : (TBG_IndOn(w) & INDICATOR_BOX_MASK)
@@ -2103,52 +2019,27 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 				   visual_set == XmINDETERMINATE
 				   ? LabG_InsensitiveGC(w)
 				   : XmParentBottomShadowGC(w),
-#endif
 				   x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
 				   visual_set ? XmSHADOW_IN : XmSHADOW_OUT);
 		    delta = DETAIL_SHADOW_THICKNESS(w) + (1 - fill);
-#if XmVERSION > 1
-		}
-		else
-		{
+		} else {
 		    delta = 0;
 		}
-#endif
-		if (dim > delta << 1)
-		{
-		    if (is_expose || TBG_FillOnSelect(w))
-		    {
+		if (dim > delta << 1) {
+		    if (is_expose || TBG_FillOnSelect(w)) {
 			XFillRectangle(XtDisplay(w), XtWindow(w),
 				       visual_set && TBG_FillOnSelect(w)
 				       ? TBG_SelectGC(w) : TBG_BackgroundGC(w),
 				       x + delta, y + delta,
 				       dim - (delta << 1), dim - (delta << 1));
 		    }
-#if XmVERSION > 1
-#if 0	/* HACK Danny */
-		    if ((TBG_IndOn(w) & ~INDICATOR_BOX_MASK) &&
-			(visual_set || !(is_expose || TBG_FillOnSelect(w))))
-		    {
-			XmeDrawIndicator(XtDisplay(w), XtWindow(w),
-					 visual_set == XmINDETERMINATE
-					 ? LabG_InsensitiveGC(w)
-					 : visual_set
-					   ? LabG_NormalGC(w)
-					   : TBG_BackgroundGC(w),
-					 x, y, dim, dim, delta,
-					 TBG_IndOn(w));
-		     }
-#else	/* Hack Danny */
-			if (visual_set == XmUNSET) {
+		    if (visual_set == XmUNSET) {
 				XFillRectangle(XtDisplayOfObject(w),
 					XtWindowOfObject(w),
 					TBG_UnselectGC(w),
 					x, y, dim, dim);
 
 				_XmDrawShadows(XtDisplay(w), XtWindow(w),
-#if XmVERSION == 1
-				   XmParentTopShadowGC(w), XmParentBottomShadowGC(w),
-#else
 				   visual_set == XmINDETERMINATE
 				   ? LabG_InsensitiveGC(w)
 				   : (TBG_IndOn(w) & INDICATOR_BOX_MASK)
@@ -2158,22 +2049,16 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 				   visual_set == XmINDETERMINATE
 				   ? LabG_InsensitiveGC(w)
 				   : XmParentBottomShadowGC(w),
-#endif
 				   x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
 				   visual_set ? XmSHADOW_IN : XmSHADOW_OUT);
 			}
-#endif
-#endif
 		}
-	    }
-	    else
-	    {
+	    } else {
 		XFillRectangle(XtDisplay(w), XtWindow(w),
 			       TBG_BackgroundGC(w), x, y, dim, dim);
 	    }
 	    break;
 
-#if XmVERSION > 1
 	case XmONE_OF_MANY_ROUND:
 	    XmeDrawCircle(XtDisplay(w), XtWindow(w),
 		visual_set ? XmParentBottomShadowGC(w) : TBG_Visible(w)
@@ -2185,7 +2070,6 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 		  ? TBG_SelectGC(w) : TBG_BackgroundGC(w) : NULL,
 		x, y, dim, dim, TBG_DetailShadowThickness(w), 1);
 		break;
-#endif
 
 	default: /* XmONE_OF_MANY[_DIAMOND] */
 	    _XmDrawDiamond(XtDisplay(w), XtWindow(w),
@@ -2196,18 +2080,10 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 		(is_expose || TBG_FillOnSelect(w))
 			? (visual_set && TBG_FillOnSelect(w))
 				? TBG_SelectGC(w)
-#if XmVERSION > 1
 				: TBG_UnselectGC(w)
-#else
-				: TBG_BackgroundGC(w)
-#endif
 			: NULL,
 		x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
-#if XmVERSION == 1
-			   fill);
-#else
 			   !fill);
-#endif
 	}
     }
 }
@@ -2316,7 +2192,6 @@ XmToggleButtonGadgetSetState(Widget w, Boolean state, Boolean notify)
 static void
 _XmUnselectColorDefault(Widget w, int offset, XrmValue *val)
 {
-#if XmVERSION > 1
 	/*
 	 * XmNunselectColor
 	 * This resource's default for a color display is XmNbackground.
@@ -2336,7 +2211,6 @@ _XmUnselectColorDefault(Widget w, int offset, XrmValue *val)
 	if (DefaultDepth(XtDisplay(w), 0) == 1) {	/* Mono */
 	} else {					/* Colour */
 	}
-#endif
 #endif
 
 	DEBUGOUT(_LtDebug(__FILE__, w, "_XmUnselectColorDefault(%p)\n",
