@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Traversal.c,v 1.1 2004/08/28 19:22:46 dannybackx Exp $
+ * $Id: Traversal.c,v 1.3 2005/03/26 06:12:17 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995-2001, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Traversal.c,v 1.1 2004/08/28 19:22:46 dannybackx Exp $";
+static const char rcsid[] = "$Id: Traversal.c,v 1.3 2005/03/26 06:12:17 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -43,6 +43,7 @@ static const char rcsid[] = "$Id: Traversal.c,v 1.1 2004/08/28 19:22:46 dannybac
 #include <Xm/ManagerP.h>
 #include <Xm/ScrolledWP.h>
 #include <Xm/DrawingAP.h>
+#include <Xm/MenuShellP.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -1806,6 +1807,12 @@ _XmGetFocusData(Widget wid)
 
 	return fd;
     }
+    else if (XtIsSubclass(wid, xmMenuShellWidgetClass) && MS_FocusData(wid) != 0)
+    {
+       XmMenuShellWidget msh = (XmMenuShellWidget)wid;
+       MS_FocusData(wid)->focus_policy = msh->menu_shell.focus_policy;
+       return (MS_FocusData(wid));
+    }
 
     DEBUGOUT(_LtDebug(__FILE__, orig,
 		      "_XmGetFocusData: not LessTif vendorshell subclass\n"));
@@ -3739,29 +3746,24 @@ XmGetTabGroup(Widget widget)
 
 
 extern Boolean
-XmProcessTraversal(Widget widget,
-		   XmTraversalDirection direction)
+XmProcessTraversal(Widget widget, XmTraversalDirection direction)
 {
-    Widget shell = _XmFindTopMostShell(widget);
-    Widget ve;
+	Widget shell = _XmFindTopMostShell(widget);
+	Widget ve;
 
-    DEBUGOUT(_LtDebug(__FILE__, widget, "XmProcessTraversal\n"));
+	DEBUGOUT(_LtDebug(__FILE__, widget, "XmProcessTraversal\n"));
 
-    ve = _LtFindVendorExt(shell);
+	ve = _LtFindVendorExt(shell);
 
-    if (!ve)
-    {
-	return False;
-    }
+	if (!ve) {
+		return False;
+	}
 
-    if (VSEP_FocusPolicy(ve) != XmEXPLICIT)
-    {
-	return False;
-    }
+	if (VSEP_FocusPolicy(ve) != XmEXPLICIT) {
+		return False;
+	}
 
-    _XmProcessTraversal(widget, direction, True);
-
-    return True;
+	return _XmMgrTraversal(widget, direction);
 }
 
 
