@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.3 2004/06/09 18:52:14 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.4 2005/08/15 19:12:32 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2001 LessTif Development Team
+ * Copyright  1997-2001, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.3 2004/06/09 18:52:14 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.4 2005/08/15 19:12:32 dannybackx Exp $";
 
 /*
  * This file contains the _XmStrings array for Motif 2.1 libXm
@@ -32,10 +32,6 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrD
 
 #include <LTconfig.h>
 
-/*
-#include <XmI/XmI.h>
-*/
-
 /*
  * The missing commas are intentional.  Let the compiler
  * concatenate the strings
@@ -906,419 +902,493 @@ const char _XmStrings[] =
 /* 12538 */ "osfUp\0"
 /* 12544 */ "FONTLIST_DEFAULT_TAG_STRING\0"
 /* 12572 */ "XmFONTLIST_DEFAULT_TAG_STRING\0"
-/* 12602 */ "tearOffTitle\0"
-/* 12615 */ "TearOffTitle\0"
-/* 12628 */ "popupHandlerCallback\0"
-/* 12649 */ "convertCallback\0"
-/* 12665 */ "destinationCallback\0"
-/* 12685 */ "selectedItem\0"
-/* 12698 */ "SelectedItem\0"
-/* 12711 */ "selectionCallback\0"
-/* 12729 */ "matchBehavior\0"
-/* 12743 */ "MatchBehavior\0"
-/* 12757 */ "noFontCallback\0"
-/* 12772 */ "textPath\0"
-/* 12781 */ "editingPath\0"
-/* 12793 */ "EditingPath\0"
-/* 12805 */ "bidirectionalCursor\0"
-/* 12825 */ "BidirectionalCursor\0"
-/* 12845 */ "collapsedStatePixmap\0"
-/* 12866 */ "detailColumnHeading\0"
-/* 12886 */ "detailCount\0"
-/* 12898 */ "detailTabList\0"
-/* 12912 */ "expandedStatePixmap\0"
-/* 12932 */ "largeCellHeight\0"
-/* 12948 */ "largeCellWidth\0"
-/* 12963 */ "layoutType\0"
-/* 12974 */ "outlineIndentation\0"
-/* 12993 */ "outlineLineStyle\0"
-/* 13010 */ "primaryOwnership\0"
-/* 13027 */ "selectionTechnique\0"
-/* 13046 */ "smallCellHeight\0"
-/* 13062 */ "smallCellWidth\0"
-/* 13077 */ "spatialStyle\0"
-/* 13090 */ "entryParent\0"
-/* 13102 */ "largeIconX\0"
-/* 13113 */ "largeIconY\0"
-/* 13124 */ "smallIconX\0"
-/* 13135 */ "smallIconY\0"
-/* 13146 */ "CollapsedStatePixmap\0"
-/* 13167 */ "DetailColumnHeading\0"
-/* 13187 */ "DetailCount\0"
-/* 13199 */ "DetailMask\0"
-/* 13210 */ "EntryViewType\0"
-/* 13224 */ "LineStyle\0"
-/* 13234 */ "DetailTabList\0"
-/* 13248 */ "ExpandedStatePixmap\0"
-/* 13268 */ "IncludeModel\0"
-/* 13281 */ "CellHeight\0"
-/* 13292 */ "CellWidth\0"
-/* 13302 */ "LayoutType\0"
-/* 13313 */ "OutlineIndentation\0"
-/* 13332 */ "PlaceModel\0"
-/* 13343 */ "PrimaryOwnership\0"
-/* 13360 */ "SelectionTechnique\0"
-/* 13379 */ "SpatialStyle\0"
-/* 13392 */ "EntryDetail\0"
-/* 13404 */ "ExpandState\0"
-/* 13416 */ "largeIcon\0"
-/* 13426 */ "largeIconMask\0"
-/* 13440 */ "largeIconPixmap\0"
-/* 13456 */ "smallIcon\0"
-/* 13466 */ "smallIconMask\0"
-/* 13480 */ "smallIconPixmap\0"
-/* 13496 */ "Icon\0"
-/* 13501 */ "ViewType\0"
-/* 13510 */ "VisualEmphasis\0"
-/* 13525 */ "currentPageNumber\0"
-/* 13543 */ "firstPageNumber\0"
-/* 13559 */ "lastPageNumber\0"
-/* 13574 */ "backPagePlacement\0"
-/* 13592 */ "backPageNumber\0"
-/* 13607 */ "backPageSize\0"
-/* 13620 */ "backPageForeground\0"
-/* 13639 */ "backPageBackground\0"
-/* 13658 */ "frameBackground\0"
-/* 13674 */ "bindingType\0"
-/* 13686 */ "bindingPixmap\0"
-/* 13700 */ "bindingWidth\0"
-/* 13713 */ "majorTabSpacing\0"
-/* 13729 */ "minorTabSpacing\0"
-/* 13745 */ "innerMarginWidth\0"
-/* 13762 */ "innerMarginHeight\0"
-/* 13780 */ "frameShadowThickness\0"
-/* 13801 */ "pageNumber\0"
-/* 13812 */ "CurrentPageNumber\0"
-/* 13830 */ "FirstPageNumber\0"
-/* 13846 */ "LastPageNumber\0"
-/* 13861 */ "BackPagePlacement\0"
-/* 13879 */ "BackPageNumber\0"
-/* 13894 */ "BackPageSize\0"
-/* 13907 */ "BackPageForeground\0"
-/* 13926 */ "BackPageBackground\0"
-/* 13945 */ "FrameBackground\0"
-/* 13961 */ "BindingType\0"
-/* 13973 */ "BindingPixmap\0"
-/* 13987 */ "BindingWidth\0"
-/* 14000 */ "MajorTabSpacing\0"
-/* 14016 */ "MinorTabSpacing\0"
-/* 14032 */ "InnerMarginWidth\0"
-/* 14049 */ "InnerMarginHeight\0"
-/* 14067 */ "PageChangeCallback\0"
-/* 14086 */ "PageNumber\0"
-/* 14097 */ "ArrowLayout\0"
-/* 14109 */ "ArrowSensitivity\0"
-/* 14126 */ "SpinBoxChildType\0"
-/* 14143 */ "arrowLayout\0"
-/* 14155 */ "ArrowLayout\0"
-/* 14167 */ "arrowSensitivity\0"
-/* 14184 */ "ArrowSensitivity\0"
-/* 14201 */ "defaultArrowSensitivity\0"
-/* 14225 */ "DefaultArrowSensitivity\0"
-/* 14249 */ "arrowSize\0"
-/* 14259 */ "ArrowSize\0"
-/* 14269 */ "spinBoxChildType\0"
-/* 14286 */ "SpinBoxChildType\0"
-/* 14303 */ "position\0"
-/* 14312 */ "numValues\0"
-/* 14322 */ "NumValues\0"
-/* 14332 */ "values\0"
-/* 14339 */ "Values\0"
-/* 14346 */ "minimumValue\0"
-/* 14359 */ "MinimumValue\0"
-/* 14372 */ "maximumValue\0"
-/* 14385 */ "MaximumValue\0"
-/* 14398 */ "incrementValue\0"
-/* 14413 */ "IncrementValue\0"
-/* 14428 */ "AutomaticSelection\0"
-/* 14447 */ "LineStyle\0"
-/* 14457 */ "EntryViewType\0"
-/* 14471 */ "Direction\0"
-/* 14481 */ "LayoutType\0"
-/* 14492 */ "PrimaryOwnership\0"
-/* 14509 */ "SelectionTechnique\0"
-/* 14528 */ "SpatialStyle\0"
-/* 14541 */ "TabList\0"
-/* 14549 */ "ViewType\0"
-/* 14558 */ "VisualEmphasis\0"
-/* 14573 */ "BindingType\0"
-/* 14585 */ "NBChildType\0"
-/* 14597 */ "entryViewType\0"
-/* 14611 */ "insensitiveStippleBitmap\0"
-/* 14636 */ "layoutDirection\0"
-/* 14652 */ "viewType\0"
-/* 14661 */ "visualEmphasis\0"
-/* 14676 */ "LayoutDirection\0"
-/* 14692 */ "snapBackMultiple\0"
-/* 14709 */ "slidingMode\0"
-/* 14721 */ "sliderVisual\0"
-/* 14734 */ "autoDragModel\0"
-/* 14748 */ "colorCalculationProc\0"
-/* 14769 */ "bitmapConversionModel\0"
-/* 14791 */ "colorAllocationProc\0"
-/* 14811 */ "selectionMode\0"
-/* 14825 */ "selectedPositions\0"
-/* 14843 */ "selectedPositionCount\0"
-/* 14865 */ "SnapBackMultiple\0"
-/* 14882 */ "SliderVisual\0"
-/* 14895 */ "SlidingMode\0"
-/* 14907 */ "AutoDragModel\0"
-/* 14921 */ "ColorCalculationProc\0"
-/* 14942 */ "BitmapConversionModel\0"
-/* 14964 */ "ColorAllocationProc\0"
-/* 14984 */ "InsensitiveStippleBitmap\0"
-/* 15009 */ "SelectionMode\0"
-/* 15023 */ "SelectedPositions\0"
-/* 15041 */ "SelectedPositionCount\0"
-/* 15063 */ "SlidingMode\0"
-/* 15075 */ "ShowArrows\0"
-/* 15086 */ "SliderVisual\0"
-/* 15099 */ "ShowValue\0"
-/* 15109 */ "AutoDragModel\0"
-/* 15123 */ "SWChildType\0"
-/* 15135 */ "BitmapConversionModel\0"
-/* 15157 */ "SelectionMode\0"
-/* 15171 */ "inputPolicy\0"
-/* 15183 */ "InputPolicy\0"
-/* 15195 */ "InputPolicy\0"
-/* 15207 */ "toggleMode\0"
-/* 15218 */ "ToggleMode\0"
-/* 15229 */ "ToggleMode\0"
-/* 15240 */ "IndicatorOn\0"
-/* 15252 */ "Set\0"
-/* 15256 */ "indeterminatePixmap\0"
-/* 15276 */ "IndeterminatePixmap\0"
-/* 15296 */ "unselectColor\0"
-/* 15310 */ "UnselectColor\0"
-/* 15324 */ "selectedPosition\0"
-/* 15341 */ "arrowSpacing\0"
-/* 15354 */ "ArrowSpacing\0"
-/* 15367 */ "MatchBehavior\0"
-/* 15381 */ "ComboBoxType\0"
-/* 15394 */ "SelectedPosition\0"
-/* 15411 */ "enableWarp\0"
-/* 15422 */ "EnableWarp\0"
-/* 15433 */ "EnableWarp\0"
-/* 15444 */ "motifVersion\0"
-/* 15457 */ "MotifVersion\0"
-/* 15470 */ "defaultGlyphPixmap\0"
-/* 15489 */ "DefaultGlyphPixmap\0"
-/* 15508 */ "Rendition\0"
-/* 15518 */ "tag\0"
-/* 15522 */ "Tag\0"
-/* 15526 */ "fontName\0"
-/* 15535 */ "FontName\0"
-/* 15544 */ "fontType\0"
-/* 15553 */ "FontType\0"
-/* 15562 */ "FontType\0"
-/* 15571 */ "loadModel\0"
-/* 15581 */ "LoadModel\0"
-/* 15591 */ "LoadModel\0"
-/* 15601 */ "tabList\0"
-/* 15609 */ "TabList\0"
-/* 15617 */ "RenditionPixel\0"
-/* 15632 */ "underlineType\0"
-/* 15646 */ "UnderlineType\0"
-/* 15660 */ "strikethruType\0"
-/* 15675 */ "StrikethruType\0"
-/* 15690 */ "LineType\0"
-/* 15699 */ "renderTable\0"
-/* 15711 */ "RenderTable\0"
-/* 15723 */ "RenderTable\0"
-/* 15735 */ "buttonRenderTable\0"
-/* 15753 */ "ButtonRenderTable\0"
-/* 15771 */ "ButtonRenderTable\0"
-/* 15789 */ "labelRenderTable\0"
-/* 15806 */ "LabelRenderTable\0"
-/* 15823 */ "LabelRenderTable\0"
-/* 15840 */ "textRenderTable\0"
-/* 15856 */ "TextRenderTable\0"
+/* 12602 */ "TopItemPosition\0"
+/* 12618 */ "tearOffTitle\0"
+/* 12631 */ "TearOffTitle\0"
+/* 12644 */ "popupHandlerCallback\0"
+/* 12665 */ "convertCallback\0"
+/* 12681 */ "destinationCallback\0"
+/* 12701 */ "selectedItem\0"
+/* 12714 */ "SelectedItem\0"
+/* 12727 */ "selectionCallback\0"
+/* 12745 */ "matchBehavior\0"
+/* 12759 */ "MatchBehavior\0"
+/* 12773 */ "noFontCallback\0"
+/* 12788 */ "textPath\0"
+/* 12797 */ "editingPath\0"
+/* 12809 */ "EditingPath\0"
+/* 12821 */ "bidirectionalCursor\0"
+/* 12841 */ "BidirectionalCursor\0"
+/* 12861 */ "collapsedStatePixmap\0"
+/* 12882 */ "detailColumnHeading\0"
+/* 12902 */ "detailCount\0"
+/* 12914 */ "detailTabList\0"
+/* 12928 */ "expandedStatePixmap\0"
+/* 12948 */ "largeCellHeight\0"
+/* 12964 */ "largeCellWidth\0"
+/* 12979 */ "layoutType\0"
+/* 12990 */ "outlineIndentation\0"
+/* 13009 */ "outlineLineStyle\0"
+/* 13026 */ "primaryOwnership\0"
+/* 13043 */ "selectionTechnique\0"
+/* 13062 */ "smallCellHeight\0"
+/* 13078 */ "smallCellWidth\0"
+/* 13093 */ "spatialStyle\0"
+/* 13106 */ "entryParent\0"
+/* 13118 */ "largeIconX\0"
+/* 13129 */ "largeIconY\0"
+/* 13140 */ "smallIconX\0"
+/* 13151 */ "smallIconY\0"
+/* 13162 */ "CollapsedStatePixmap\0"
+/* 13183 */ "DetailColumnHeading\0"
+/* 13203 */ "DetailCount\0"
+/* 13215 */ "DetailMask\0"
+/* 13226 */ "EntryViewType\0"
+/* 13240 */ "LineStyle\0"
+/* 13250 */ "DetailTabList\0"
+/* 13264 */ "ExpandedStatePixmap\0"
+/* 13284 */ "IncludeModel\0"
+/* 13297 */ "CellHeight\0"
+/* 13308 */ "CellWidth\0"
+/* 13318 */ "LayoutType\0"
+/* 13329 */ "OutlineIndentation\0"
+/* 13348 */ "PlaceModel\0"
+/* 13359 */ "PrimaryOwnership\0"
+/* 13376 */ "SelectionTechnique\0"
+/* 13395 */ "SpatialStyle\0"
+/* 13408 */ "EntryDetail\0"
+/* 13420 */ "ExpandState\0"
+/* 13432 */ "largeIcon\0"
+/* 13442 */ "largeIconMask\0"
+/* 13456 */ "largeIconPixmap\0"
+/* 13472 */ "smallIcon\0"
+/* 13482 */ "smallIconMask\0"
+/* 13496 */ "smallIconPixmap\0"
+/* 13512 */ "Icon\0"
+/* 13517 */ "ViewType\0"
+/* 13526 */ "VisualEmphasis\0"
+/* 13541 */ "currentPageNumber\0"
+/* 13559 */ "firstPageNumber\0"
+/* 13575 */ "lastPageNumber\0"
+/* 13590 */ "backPagePlacement\0"
+/* 13608 */ "backPageNumber\0"
+/* 13623 */ "backPageSize\0"
+/* 13636 */ "backPageForeground\0"
+/* 13655 */ "backPageBackground\0"
+/* 13674 */ "frameBackground\0"
+/* 13690 */ "bindingType\0"
+/* 13702 */ "bindingPixmap\0"
+/* 13716 */ "bindingWidth\0"
+/* 13729 */ "majorTabSpacing\0"
+/* 13745 */ "minorTabSpacing\0"
+/* 13761 */ "innerMarginWidth\0"
+/* 13778 */ "innerMarginHeight\0"
+/* 13796 */ "frameShadowThickness\0"
+/* 13817 */ "pageNumber\0"
+/* 13828 */ "CurrentPageNumber\0"
+/* 13846 */ "FirstPageNumber\0"
+/* 13862 */ "LastPageNumber\0"
+/* 13877 */ "BackPagePlacement\0"
+/* 13895 */ "BackPageNumber\0"
+/* 13910 */ "BackPageSize\0"
+/* 13923 */ "BackPageForeground\0"
+/* 13942 */ "BackPageBackground\0"
+/* 13961 */ "FrameBackground\0"
+/* 13977 */ "BindingType\0"
+/* 13989 */ "BindingPixmap\0"
+/* 14003 */ "BindingWidth\0"
+/* 14016 */ "MajorTabSpacing\0"
+/* 14032 */ "MinorTabSpacing\0"
+/* 14048 */ "InnerMarginWidth\0"
+/* 14065 */ "InnerMarginHeight\0"
+/* 14083 */ "PageChangeCallback\0"
+/* 14102 */ "PageNumber\0"
+/* 14113 */ "ArrowLayout\0"
+/* 14125 */ "ArrowSensitivity\0"
+/* 14142 */ "SpinBoxChildType\0"
+/* 14159 */ "arrowLayout\0"
+/* 14171 */ "ArrowLayout\0"
+/* 14183 */ "arrowSensitivity\0"
+/* 14200 */ "ArrowSensitivity\0"
+/* 14217 */ "defaultArrowSensitivity\0"
+/* 14241 */ "DefaultArrowSensitivity\0"
+/* 14265 */ "arrowSize\0"
+/* 14275 */ "ArrowSize\0"
+/* 14285 */ "spinBoxChildType\0"
+/* 14302 */ "SpinBoxChildType\0"
+/* 14319 */ "position\0"
+/* 14328 */ "numValues\0"
+/* 14338 */ "NumValues\0"
+/* 14348 */ "values\0"
+/* 14355 */ "Values\0"
+/* 14362 */ "minimumValue\0"
+/* 14375 */ "MinimumValue\0"
+/* 14388 */ "maximumValue\0"
+/* 14401 */ "MaximumValue\0"
+/* 14414 */ "incrementValue\0"
+/* 14429 */ "IncrementValue\0"
+/* 14444 */ "AutomaticSelection\0"
+/* 14463 */ "LineStyle\0"
+/* 14473 */ "EntryViewType\0"
+/* 14487 */ "Direction\0"
+/* 14497 */ "LayoutType\0"
+/* 14508 */ "PrimaryOwnership\0"
+/* 14525 */ "SelectionTechnique\0"
+/* 14544 */ "SpatialStyle\0"
+/* 14557 */ "TabList\0"
+/* 14565 */ "ViewType\0"
+/* 14574 */ "VisualEmphasis\0"
+/* 14589 */ "BindingType\0"
+/* 14601 */ "NBChildType\0"
+/* 14613 */ "entryViewType\0"
+/* 14627 */ "insensitiveStippleBitmap\0"
+/* 14652 */ "layoutDirection\0"
+/* 14668 */ "viewType\0"
+/* 14677 */ "visualEmphasis\0"
+/* 14692 */ "LayoutDirection\0"
+/* 14708 */ "snapBackMultiple\0"
+/* 14725 */ "slidingMode\0"
+/* 14737 */ "sliderVisual\0"
+/* 14750 */ "autoDragModel\0"
+/* 14764 */ "colorCalculationProc\0"
+/* 14785 */ "bitmapConversionModel\0"
+/* 14807 */ "colorAllocationProc\0"
+/* 14827 */ "selectionMode\0"
+/* 14841 */ "selectedPositions\0"
+/* 14859 */ "selectedPositionCount\0"
+/* 14881 */ "SnapBackMultiple\0"
+/* 14898 */ "SliderVisual\0"
+/* 14911 */ "SlidingMode\0"
+/* 14923 */ "AutoDragModel\0"
+/* 14937 */ "ColorCalculationProc\0"
+/* 14958 */ "BitmapConversionModel\0"
+/* 14980 */ "ColorAllocationProc\0"
+/* 15000 */ "InsensitiveStippleBitmap\0"
+/* 15025 */ "SelectionMode\0"
+/* 15039 */ "SelectedPositions\0"
+/* 15057 */ "SelectedPositionCount\0"
+/* 15079 */ "SlidingMode\0"
+/* 15091 */ "ShowArrows\0"
+/* 15102 */ "SliderVisual\0"
+/* 15115 */ "ShowValue\0"
+/* 15125 */ "AutoDragModel\0"
+/* 15139 */ "SWChildType\0"
+/* 15151 */ "BitmapConversionModel\0"
+/* 15173 */ "SelectionMode\0"
+/* 15187 */ "inputPolicy\0"
+/* 15199 */ "InputPolicy\0"
+/* 15211 */ "InputPolicy\0"
+/* 15223 */ "toggleMode\0"
+/* 15234 */ "ToggleMode\0"
+/* 15245 */ "ToggleMode\0"
+/* 15256 */ "IndicatorOn\0"
+/* 15268 */ "Set\0"
+/* 15272 */ "indeterminatePixmap\0"
+/* 15292 */ "IndeterminatePixmap\0"
+/* 15312 */ "unselectColor\0"
+/* 15326 */ "UnselectColor\0"
+/* 15340 */ "selectedPosition\0"
+/* 15357 */ "arrowSpacing\0"
+/* 15370 */ "ArrowSpacing\0"
+/* 15383 */ "MatchBehavior\0"
+/* 15397 */ "ComboBoxType\0"
+/* 15410 */ "SelectedPosition\0"
+/* 15427 */ "enableWarp\0"
+/* 15438 */ "EnableWarp\0"
+/* 15449 */ "EnableWarp\0"
+/* 15460 */ "motifVersion\0"
+/* 15473 */ "MotifVersion\0"
+/* 15486 */ "defaultGlyphPixmap\0"
+/* 15505 */ "DefaultGlyphPixmap\0"
+/* 15524 */ "Rendition\0"
+/* 15534 */ "tag\0"
+/* 15538 */ "Tag\0"
+/* 15542 */ "fontName\0"
+/* 15551 */ "FontName\0"
+/* 15560 */ "fontType\0"
+/* 15569 */ "FontType\0"
+/* 15578 */ "FontType\0"
+/* 15587 */ "loadModel\0"
+/* 15597 */ "LoadModel\0"
+/* 15607 */ "LoadModel\0"
+/* 15617 */ "tabList\0"
+/* 15625 */ "TabList\0"
+/* 15633 */ "RenditionPixel\0"
+/* 15648 */ "underlineType\0"
+/* 15662 */ "UnderlineType\0"
+/* 15676 */ "strikethruType\0"
+/* 15691 */ "StrikethruType\0"
+/* 15706 */ "LineType\0"
+/* 15715 */ "renderTable\0"
+/* 15727 */ "RenderTable\0"
+/* 15739 */ "RenderTable\0"
+/* 15751 */ "buttonRenderTable\0"
+/* 15769 */ "ButtonRenderTable\0"
+/* 15787 */ "ButtonRenderTable\0"
+/* 15805 */ "labelRenderTable\0"
+/* 15822 */ "LabelRenderTable\0"
+/* 15839 */ "LabelRenderTable\0"
+/* 15856 */ "textRenderTable\0"
 /* 15872 */ "TextRenderTable\0"
-/* 15888 */ "dragStartCallback\0"
-/* 15906 */ "noRenditionCallback\0"
-/* 15926 */ "XmAS_IS\0"
-/* 15934 */ "IsWhiteSpaceMethod\0"
-/* 15953 */ "IsScanBreakMethod\0"
-/* 15971 */ "CharDirection\0"
-/* 15985 */ "InitialCharsDirection\0"
-/* 16007 */ "patternType\0"
-/* 16019 */ "substitute\0"
-/* 16030 */ "invokeParseProc\0"
-/* 16046 */ "includeStatus\0"
-/* 16060 */ "osfBackTab\0"
-/* 16071 */ "osfBeginData\0"
-/* 16084 */ "osfDeselectAll\0"
-/* 16099 */ "osfEndData\0"
-/* 16110 */ "osfEscape\0"
-/* 16120 */ "osfExtend\0"
-/* 16130 */ "osfLeftLine\0"
-/* 16142 */ "osfNext\0"
-/* 16150 */ "osfNextField\0"
-/* 16163 */ "osfNextMenu\0"
-/* 16175 */ "osfNextMinor\0"
-/* 16188 */ "osfPrevField\0"
-/* 16201 */ "osfPrevMenu\0"
-/* 16213 */ "osfPrior\0"
-/* 16222 */ "osfPriorMinor\0"
-/* 16236 */ "osfReselect\0"
-/* 16248 */ "osfRestore\0"
-/* 16259 */ "osfRightLine\0"
-/* 16272 */ "osfSelectAll\0"
-/* 16285 */ "osfSwitchDirection\0"
-/* 16304 */ "notebookChildType\0"
-/* 16322 */ "NotebookChildType\0"
-/* 16340 */ "NotebookChildType\0"
-/* 16358 */ "scrolledWindowChildType\0"
-/* 16382 */ "ScrolledWindowChildType\0"
-/* 16406 */ "ScrolledWindowChildType\0"
-/* 16430 */ "selectedObjects\0"
-/* 16446 */ "SelectedObjects\0"
-/* 16462 */ "selectedObjectCount\0"
-/* 16482 */ "SelectedObjectCount\0"
-/* 16502 */ "comboBoxType\0"
-/* 16515 */ "ComboBoxType\0"
-/* 16528 */ "tabValue\0"
-/* 16537 */ "offsetModel\0"
-/* 16549 */ "decimal\0"
-/* 16557 */ "cstextValue\0"
-/* 16569 */ "CSTextValue\0"
-/* 16581 */ "TopItemPosition\0"
-/* 16597 */ "detail\0"
-/* 16604 */ "Detail\0"
-/* 16611 */ "detailCount\0"
-/* 16623 */ "DetailCount\0"
-/* 16635 */ "containerID\0"
-/* 16647 */ "ContainerID\0"
-/* 16659 */ "CLIENT_WINDOW\0"
-/* 16673 */ "CLIP_TEMPORARY\0"
-/* 16688 */ "CLIPBOARD\0"
-/* 16698 */ "COMPOUND_TEXT\0"
-/* 16712 */ "DELETE\0"
-/* 16719 */ "FILE\0"
-/* 16724 */ "FILE_NAME\0"
-/* 16734 */ "INCR\0"
-/* 16739 */ "INSERT_PROPERTY\0"
-/* 16755 */ "INSERT_SELECTION\0"
-/* 16772 */ "LENGTH\0"
-/* 16779 */ "LINK_SELECTION\0"
-/* 16794 */ "_MOTIF_ATOM_0\0"
-/* 16808 */ "_MOTIF_BINDINGS\0"
-/* 16824 */ "_MOTIF_DEFAULT_BINDINGS\0"
-/* 16848 */ "_MOTIF_CANCEL_DROP_EFFECT\0"
-/* 16874 */ "_MOTIF_CLIP_HEADER\0"
-/* 16893 */ "_MOTIF_CLIP_DATA_REQUEST\0"
-/* 16918 */ "_MOTIF_CLIP_DATA_DELETE\0"
-/* 16942 */ "_MOTIF_CLIP_ITEM\0"
-/* 16959 */ "_MOTIF_CLIP_LOCK\0"
-/* 16976 */ "_MOTIF_CLIP_LOCK_ACCESS_VALID\0"
-/* 17006 */ "_MOTIF_CLIP_MESSAGE\0"
-/* 17026 */ "_MOTIF_CLIP_NEXT_ID\0"
-/* 17046 */ "_MOTIF_CLIP_TIME\0"
-/* 17063 */ "_MOTIF_CLIPBOARD_TARGETS\0"
-/* 17088 */ "_MOTIF_COMPOUND_STRING\0"
-/* 17111 */ "_MOTIF_DEFERRED_CLIPBOARD_TARGETS\0"
-/* 17145 */ "_MOTIF_DESTINATION\0"
-/* 17164 */ "_MOTIF_DRAG_OFFSET\0"
-/* 17183 */ "_MOTIF_DROP\0"
-/* 17195 */ "_MOTIF_ENCODING_REGISTRY\0"
-/* 17220 */ "_MOTIF_EXPORT_TARGETS\0"
-/* 17242 */ "_MOTIF_LOSE_SELECTION\0"
-/* 17264 */ "_MOTIF_RENDER_TABLE\0"
-/* 17284 */ "_MOTIF_WM_QUERY\0"
-/* 17300 */ "_MOTIF_WM_ALL_CLIENTS\0"
-/* 17322 */ "MULTIPLE\0"
-/* 17331 */ "NULL\0"
-/* 17336 */ "TARGETS\0"
-/* 17344 */ "TEXT\0"
-/* 17349 */ "TIMESTAMP\0"
-/* 17359 */ "WM_STATE\0"
-/* 17368 */ "XmTRANSFER_SUCCESS\0"
-/* 17387 */ "XmTRANSFER_FAILURE\0"
-/* 17406 */ "pathMode\0"
-/* 17415 */ "PathMode\0"
-/* 17424 */ "PathMode\0"
-/* 17433 */ "fileFilterStyle\0"
-/* 17449 */ "FileFilterStyle\0"
-/* 17465 */ "FileFilterStyle\0"
-/* 17481 */ "dirTextLabelString\0"
-/* 17500 */ "DirTextLabelString\0"
-/* 17519 */ "enableBtn1Transfer\0"
-/* 17538 */ "EnableBtn1Transfer\0"
-/* 17557 */ "enableButtonTab\0"
-/* 17573 */ "EnableButtonTab\0"
-/* 17589 */ "enableEtchedInMenu\0"
-/* 17608 */ "EnableEtchedInMenu\0"
-/* 17627 */ "defaultButtonEmphasis\0"
-/* 17649 */ "DefaultButtonEmphasis\0"
-/* 17671 */ "DefaultButtonEmphasis\0"
-/* 17693 */ "enableToggleColor\0"
-/* 17711 */ "EnableToggleColor\0"
-/* 17729 */ "enableToggleVisual\0"
-/* 17748 */ "EnableToggleVisual\0"
-/* 17767 */ "enableDragIcon\0"
-/* 17782 */ "EnableDragIcon\0"
-/* 17797 */ "enableUnselectableDrag\0"
-/* 17820 */ "EnableUnselectableDrag\0"
-/* 17843 */ "dragOverActiveMode\0"
-/* 17862 */ "DragOverActiveMode\0"
-/* 17881 */ "installColormap\0"
-/* 17897 */ "InstallColormap\0"
-/* 17913 */ "OwnerEvents\0"
-/* 17925 */ "ownerEvents\0"
-/* 17937 */ "GrabStyle\0"
-/* 17947 */ "grabStyle\0"
-/* 17957 */ "foregroundState\0"
-/* 17973 */ "backgroundState\0"
-/* 17989 */ "GroundState\0"
-/* 18001 */ "GroundState\0"
-/* 18013 */ "SelectColor\0"
-/* 18025 */ "LargeIconPixmap\0"
-/* 18041 */ "SmallIconPixmap\0"
-/* 18057 */ "outlineState\0"
-/* 18070 */ "OutlineState\0"
-/* 18083 */ "OutlineState\0"
-/* 18096 */ "spatialIncludeModel\0"
-/* 18116 */ "SpatialIncludeModel\0"
-/* 18136 */ "SpatialIncludeModel\0"
-/* 18156 */ "spatialResizeModel\0"
-/* 18175 */ "SpatialResizeModel\0"
-/* 18194 */ "SpatialResizeModel\0"
-/* 18213 */ "spatialSnapModel\0"
-/* 18230 */ "SpatialSnapModel\0"
-/* 18247 */ "SpatialSnapModel\0"
-/* 18264 */ "detailColumnHeadingCount\0"
-/* 18289 */ "DetailColumnHeadingCount\0"
-/* 18314 */ "detailOrder\0"
-/* 18326 */ "DetailOrder\0"
-/* 18338 */ "CardinalList\0"
-/* 18351 */ "detailOrderCount\0"
-/* 18368 */ "DetailOrderCount\0"
-/* 18385 */ "outlineColumnWidth\0"
-/* 18404 */ "OutlineColumnWidth\0"
-/* 18423 */ "outlineChangedCallback\0"
-/* 18446 */ "OutlineChangedCallback\0"
-/* 18469 */ "outlineButtonPolicy\0"
-/* 18489 */ "OutlineButtonPolicy\0"
-/* 18509 */ "OutlineButtonPolicy\0"
-/* 18529 */ "CSTextSource\0"
-/* 18542 */ "DefaultVirtualBindings\0"
-/* 18565 */ "defaultVirtualBindings\0"
-/* 18588 */ "Resizable\0"
-/* 18598 */ "DynamicPixmap\0"
-/* 18612 */ "pageChangedCallback\0"
-/* 18632 */ "area\0"
-/* 18637 */ "detailShadowThickness\0"
-/* 18659 */ "sliderMark\0"
-/* 18670 */ "SliderMark\0"
-/* 18681 */ "SliderMark\0"
-/* 18692 */ "EnableBtn1Transfer\0"
-/* 18711 */ "renditionBackground\0"
-/* 18731 */ "renditionForeground\0"
-/* 18751 */ "RenditionBackground\0"
-/* 18771 */ "RenditionForeground\0"
-/* 18791 */ "indeterminateInsensitivePixmap\0"
-/* 18822 */ "IndeterminateInsensitivePixmap\0"
-/* 18853 */ "frameChildType\0"
-/* 18868 */ "FrameChildType\0"
-/* ????? */ 
+/* 15888 */ "TextRenderTable\0"
+/* 15904 */ "dragStartCallback\0"
+/* 15922 */ "noRenditionCallback\0"
+/* 15942 */ "XmAS_IS\0"
+/* 15950 */ "IsWhiteSpaceMethod\0"
+/* 15969 */ "IsScanBreakMethod\0"
+/* 15987 */ "CharDirection\0"
+/* 16001 */ "InitialCharsDirection\0"
+/* 16023 */ "patternType\0"
+/* 16035 */ "substitute\0"
+/* 16046 */ "invokeParseProc\0"
+/* 16062 */ "includeStatus\0"
+/* 16076 */ "osfBackTab\0"
+/* 16087 */ "osfBeginData\0"
+/* 16100 */ "osfDeselectAll\0"
+/* 16115 */ "osfEndData\0"
+/* 16126 */ "osfEscape\0"
+/* 16136 */ "osfExtend\0"
+/* 16146 */ "osfLeftLine\0"
+/* 16158 */ "osfNext\0"
+/* 16166 */ "osfNextField\0"
+/* 16179 */ "osfNextMenu\0"
+/* 16191 */ "osfNextMinor\0"
+/* 16204 */ "osfPrevField\0"
+/* 16217 */ "osfPrevMenu\0"
+/* 16229 */ "osfPrior\0"
+/* 16238 */ "osfPriorMinor\0"
+/* 16252 */ "osfReselect\0"
+/* 16264 */ "osfRestore\0"
+/* 16275 */ "osfRightLine\0"
+/* 16288 */ "osfSelectAll\0"
+/* 16301 */ "osfSwitchDirection\0"
+/* 16320 */ "notebookChildType\0"
+/* 16338 */ "NotebookChildType\0"
+/* 16356 */ "NotebookChildType\0"
+/* 16374 */ "scrolledWindowChildType\0"
+/* 16398 */ "ScrolledWindowChildType\0"
+/* 16422 */ "ScrolledWindowChildType\0"
+/* 16446 */ "selectedObjects\0"
+/* 16462 */ "SelectedObjects\0"
+/* 16478 */ "selectedObjectCount\0"
+/* 16498 */ "SelectedObjectCount\0"
+/* 16518 */ "comboBoxType\0"
+/* 16531 */ "ComboBoxType\0"
+/* 16544 */ "tabValue\0"
+/* 16553 */ "offsetModel\0"
+/* 16565 */ "decimal\0"
+/* 16573 */ "detail\0"
+/* 16580 */ "Detail\0"
+/* 16587 */ "detailCount\0"
+/* 16599 */ "DetailCount\0"
+/* 16611 */ "containerID\0"
+/* 16623 */ "ContainerID\0"
+/* 16635 */ "CLIENT_WINDOW\0"
+/* 16649 */ "CLIP_TEMPORARY\0"
+/* 16664 */ "CLIPBOARD\0"
+/* 16674 */ "COMPOUND_TEXT\0"
+/* 16688 */ "DELETE\0"
+/* 16695 */ "FILE\0"
+/* 16700 */ "FILE_NAME\0"
+/* 16710 */ "INCR\0"
+/* 16715 */ "INSERT_PROPERTY\0"
+/* 16731 */ "INSERT_SELECTION\0"
+/* 16748 */ "LENGTH\0"
+/* 16755 */ "LINK_SELECTION\0"
+/* 16770 */ "_MOTIF_ATOM_0\0"
+/* 16784 */ "_MOTIF_BINDINGS\0"
+/* 16800 */ "_MOTIF_DEFAULT_BINDINGS\0"
+/* 16824 */ "_MOTIF_CANCEL_DROP_EFFECT\0"
+/* 16850 */ "_MOTIF_CLIP_HEADER\0"
+/* 16869 */ "_MOTIF_CLIP_DATA_REQUEST\0"
+/* 16894 */ "_MOTIF_CLIP_DATA_DELETE\0"
+/* 16918 */ "_MOTIF_CLIP_ITEM\0"
+/* 16935 */ "_MOTIF_CLIP_LOCK\0"
+/* 16952 */ "_MOTIF_CLIP_LOCK_ACCESS_VALID\0"
+/* 16982 */ "_MOTIF_CLIP_MESSAGE\0"
+/* 17002 */ "_MOTIF_CLIP_NEXT_ID\0"
+/* 17022 */ "_MOTIF_CLIP_TIME\0"
+/* 17039 */ "_MOTIF_CLIPBOARD_TARGETS\0"
+/* 17064 */ "_MOTIF_COMPOUND_STRING\0"
+/* 17087 */ "_MOTIF_DEFERRED_CLIPBOARD_TARGETS\0"
+/* 17121 */ "_MOTIF_DESTINATION\0"
+/* 17140 */ "_MOTIF_DRAG_OFFSET\0"
+/* 17159 */ "_MOTIF_DROP\0"
+/* 17171 */ "_MOTIF_ENCODING_REGISTRY\0"
+/* 17196 */ "_MOTIF_EXPORT_TARGETS\0"
+/* 17218 */ "_MOTIF_LOSE_SELECTION\0"
+/* 17240 */ "_MOTIF_RENDER_TABLE\0"
+/* 17260 */ "_MOTIF_WM_QUERY\0"
+/* 17276 */ "_MOTIF_WM_ALL_CLIENTS\0"
+/* 17298 */ "MULTIPLE\0"
+/* 17307 */ "NULL\0"
+/* 17312 */ "TARGETS\0"
+/* 17320 */ "TEXT\0"
+/* 17325 */ "TIMESTAMP\0"
+/* 17335 */ "WM_STATE\0"
+/* 17344 */ "XmTRANSFER_SUCCESS\0"
+/* 17363 */ "XmTRANSFER_FAILURE\0"
+/* 17382 */ "pathMode\0"
+/* 17391 */ "PathMode\0"
+/* 17400 */ "PathMode\0"
+/* 17409 */ "fileFilterStyle\0"
+/* 17425 */ "FileFilterStyle\0"
+/* 17441 */ "FileFilterStyle\0"
+/* 17457 */ "dirTextLabelString\0"
+/* 17476 */ "DirTextLabelString\0"
+/* 17495 */ "enableBtn1Transfer\0"
+/* 17514 */ "EnableBtn1Transfer\0"
+/* 17533 */ "enableButtonTab\0"
+/* 17549 */ "EnableButtonTab\0"
+/* 17565 */ "enableEtchedInMenu\0"
+/* 17584 */ "EnableEtchedInMenu\0"
+/* 17603 */ "defaultButtonEmphasis\0"
+/* 17625 */ "DefaultButtonEmphasis\0"
+/* 17647 */ "DefaultButtonEmphasis\0"
+/* 17669 */ "enableToggleColor\0"
+/* 17687 */ "EnableToggleColor\0"
+/* 17705 */ "enableToggleVisual\0"
+/* 17724 */ "EnableToggleVisual\0"
+/* 17743 */ "enableDragIcon\0"
+/* 17758 */ "EnableDragIcon\0"
+/* 17773 */ "enableUnselectableDrag\0"
+/* 17796 */ "EnableUnselectableDrag\0"
+/* 17819 */ "dragOverActiveMode\0"
+/* 17838 */ "DragOverActiveMode\0"
+/* 17857 */ "installColormap\0"
+/* 17873 */ "InstallColormap\0"
+/* 17889 */ "OwnerEvents\0"
+/* 17901 */ "ownerEvents\0"
+/* 17913 */ "GrabStyle\0"
+/* 17923 */ "grabStyle\0"
+/* 17933 */ "foregroundState\0"
+/* 17949 */ "backgroundState\0"
+/* 17965 */ "GroundState\0"
+/* 17977 */ "GroundState\0"
+/* 17989 */ "SelectColor\0"
+/* 18001 */ "LargeIconPixmap\0"
+/* 18017 */ "SmallIconPixmap\0"
+/* 18033 */ "outlineState\0"
+/* 18046 */ "OutlineState\0"
+/* 18059 */ "OutlineState\0"
+/* 18072 */ "spatialIncludeModel\0"
+/* 18092 */ "SpatialIncludeModel\0"
+/* 18112 */ "SpatialIncludeModel\0"
+/* 18132 */ "spatialResizeModel\0"
+/* 18151 */ "SpatialResizeModel\0"
+/* 18170 */ "SpatialResizeModel\0"
+/* 18189 */ "spatialSnapModel\0"
+/* 18206 */ "SpatialSnapModel\0"
+/* 18223 */ "SpatialSnapModel\0"
+/* 18240 */ "detailColumnHeadingCount\0"
+/* 18265 */ "DetailColumnHeadingCount\0"
+/* 18290 */ "detailOrder\0"
+/* 18302 */ "DetailOrder\0"
+/* 18314 */ "CardinalList\0"
+/* 18327 */ "detailOrderCount\0"
+/* 18344 */ "DetailOrderCount\0"
+/* 18361 */ "outlineColumnWidth\0"
+/* 18380 */ "OutlineColumnWidth\0"
+/* 18399 */ "outlineChangedCallback\0"
+/* 18422 */ "OutlineChangedCallback\0"
+/* 18445 */ "outlineButtonPolicy\0"
+/* 18465 */ "OutlineButtonPolicy\0"
+/* 18485 */ "OutlineButtonPolicy\0"
+/* 18505 */ "DefaultVirtualBindings\0"
+/* 18528 */ "defaultVirtualBindings\0"
+/* 18551 */ "Resizable\0"
+/* 18561 */ "DynamicPixmap\0"
+/* 18575 */ "pageChangedCallback\0"
+/* 18595 */ "area\0"
+/* 18600 */ "detailShadowThickness\0"
+/* 18622 */ "sliderMark\0"
+/* 18633 */ "SliderMark\0"
+/* 18644 */ "SliderMark\0"
+/* 18655 */ "EnableBtn1Transfer\0"
+/* 18674 */ "renditionBackground\0"
+/* 18694 */ "renditionForeground\0"
+/* 18714 */ "RenditionBackground\0"
+/* 18734 */ "RenditionForeground\0"
+/* 18754 */ "indeterminateInsensitivePixmap\0"
+/* 18785 */ "IndeterminateInsensitivePixmap\0"
+/* 18816 */ "frameChildType\0"
+/* 18831 */ "FrameChildType\0"
+/* 18846 */ "textField\0"
+/* 18856 */ "TextField\0"
+/* 18866 */ "enableThinThickness\0"
+/* 18886 */ "EnableThinThickness\0"
+/* 18906 */ "primaryColorSetId\0"
+/* 18924 */ "PrimaryColorSetId\0"
+/* 18942 */ "secondaryColorSetId\0"
+/* 18962 */ "SecondaryColorSetId\0"
+/* 18982 */ "textColorSetId\0"
+/* 18997 */ "TextColorSetId\0"
+/* 19012 */ "activeColorSetId\0"
+/* 19029 */ "ActiveColorSetId\0"
+/* 19046 */ "inactiveColorSetId\0"
+/* 19065 */ "InactiveColorSetId\0"
+/* 19084 */ "useColorObj\0"
+/* 19096 */ "UseColorObj\0"
+/* 19108 */ "useTextColor\0"
+/* 19121 */ "UseTextColor\0"
+/* 19134 */ "useTextColorForList\0"
+/* 19154 */ "UseTextColorForList\0"
+/* 19174 */ "useMask\0"
+/* 19182 */ "UseMask\0"
+/* 19190 */ "useMultiColorIcons\0"
+/* 19209 */ "UseMultiColorIcons\0"
+/* 19228 */ "useIconFileCache\0"
+/* 19245 */ "UseIconFileCache\0"
+/* 19262 */ "Pixel Sets\0"
+/* 19273 */ "Customize Data:\0"
+/* 19289 */ "ColorServer\0"
+/* 19301 */ "list\0"
+/* 19306 */ "List\0"
+/* 19311 */ "arrowOrientation\0"
+/* 19328 */ "ArrowOrientation\0"
+/* 19345 */ "ArrowOrientation\0"
+/* 19362 */ "positionType\0"
+/* 19375 */ "PositionType\0"
+/* 19388 */ "PositionType\0"
+/* 19401 */ "wrap\0"
+/* 19406 */ "Wrap\0"
+/* 19411 */ "positionMode\0"
+/* 19424 */ "PositionMode\0"
+/* 19437 */ "PositionMode\0"
+/* 19450 */ "printOrientation\0"
+/* 19467 */ "PrintOrientation\0"
+/* 19484 */ "printOrientations\0"
+/* 19502 */ "PrintOrientations\0"
+/* 19520 */ "printResolution\0"
+/* 19536 */ "PrintResolution\0"
+/* 19552 */ "printResolutions\0"
+/* 19569 */ "PrintResolutions\0"
+/* 19586 */ "defaultPixmapResolution\0"
+/* 19610 */ "DefaultPixmapResolution\0"
+/* 19634 */ "startJobCallback\0"
+/* 19651 */ "endJobCallback\0"
+/* 19666 */ "pageSetupCallback\0"
+/* 19684 */ "pdmNotificationCallback\0"
+/* 19708 */ "minX\0"
+/* 19713 */ "minY\0"
+/* 19718 */ "maxX\0"
+/* 19723 */ "maxY\0"
+/* 19728 */ "MinX\0"
+/* 19733 */ "MinY\0"
+/* 19738 */ "MaxX\0"
+/* 19743 */ "MaxY\0"
+/* 19748 */ "preeditStartCallback\0"
+/* 19769 */ "preeditDoneCallback\0"
+/* 19789 */ "preeditDrawCallback\0"
+/* 19809 */ "preeditCaretCallback\0"
+/* 19830 */ "verifyPreedit\0"
+/* 19844 */ "VerifyPreedit\0"
+/* 19858 */ "enableMultiKeyBindings\0"
+/* 19881 */ "EnableMultiKeyBindings\0"
+/* 19904 */ "ButtonFontList\0"
+/* 19919 */ "LabelFontList\0"
+/* 19933 */ "TextFontList\0"
+/* 19946 */ "SDT Pixel Set\0"
+/* 19960 */ "50_foreground\0"
+/* 19974 */ "unspecified_pixmap\0"
 "\0";
