@@ -1,10 +1,12 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/arrowbg/test1.c,v 1.6 2002/05/01 15:39:21 amai Exp $ */
+
+#include <stdlib.h>
+#include <stdio.h>
 
 #include <Xm/ArrowBG.h>
 #include <Xm/BulletinB.h>
-#include <stdio.h>
 
 #include "../../common/Test.h"
-#include "../../common/DumpLayout.h"
 
 void
 cb(Widget w, XtPointer userData, XtPointer cbs) {
