@@ -1,4 +1,5 @@
 /*
+ $Header: /cvsroot/lesstif/lesstif/test/Xm/filesb/test10.c,v 1.10 2002/05/01 15:39:21 amai Exp $
 From:        Karsten Jensen <kbwj@diku.dk>
 To:          lesstif@hungry.com
 Subject:     Re: FileSelection patch
@@ -22,17 +23,16 @@ Karsten
 
 */
 
-/*
- * test/Xm/filesb/test1.c - print value of FileSB resources from a
-callback
- * $Id: test10.c,v 1.8 2001/05/18 12:49:24 rwscott Exp $
- */
-#include <Xm/Xm.h>
-#include <Xm/FileSBP.h>
+#include <stdlib.h>
 #include <stdio.h>
 
+#include <Xm/Xm.h>
+#include <Xm/FileSBP.h>
+
 #include "../../common/Test.h"
-#include "../../common/DumpLayout.h"
+
+#include "mkdirtree.h"
+
 
 static char *FallBack[] = {
 		"*.geometrySlop: 0",
