@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/lesstif/lesstif/test/Xm/filesb/test13.c,v 1.7 2001/03/13 21:21:30 amai Exp $
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/filesb/test13.c,v 1.8 2001/06/15 09:17:36 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -10,9 +10,11 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/FileSB.h>
 
+
 static char *FallBack[] = {
 		"*.geometrySlop: 0",
 		NULL
@@ -38,14 +40,14 @@ main(int argc, char *argv[])
 	w = XtCreateWidget("name", xmFileSelectionBoxWidgetClass, shell, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)((char *)after - (char *)before) > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		*/
-		total += (int)after - (int)before;
+		total += (int)((char *)after - (char *)before);
 	    }
 	    diff = iter;
 	}
