@@ -1,5 +1,8 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/filesb/test9.c,v 1.14 2002/05/01 15:39:21 amai Exp $ */
+
 #include <stdio.h>
 #include <stdlib.h>
+
 #include <Xm/Xm.h>
 #include <Xm/Label.h>
 #include <Xm/TextF.h>
@@ -13,7 +16,8 @@
 #include <Xm/MessageB.h>
 
 #include "../../common/Test.h"
-#include "../../common/DumpLayout.h"
+
+#include "mkdirtree.h"
 
 XmQualifyProc (*defaultQualifyProc)();
 Widget In;
