@@ -1,15 +1,14 @@
-/* $Id: test10.c,v 1.5 1999/10/26 08:33:39 amai Exp $
+/* $Id: test10.c,v 1.7 2002/05/01 15:54:45 amai Exp $
    Test 10.c: Test if geometry is correct after adding items .. similar to
               combobox tests. 
 */
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
 #include <Xm/BulletinB.h>
 #include <Xm/ListP.h>
-#include "XdbPrintTree.c"
-#include "XdbPrintResources.c"
+
+#include "../../common/Test.h"
 
 int
 main(int argc, char **argv)
