@@ -1,6 +1,11 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/list/test4.c,v 1.7 2002/05/01 15:54:45 amai Exp $ */
+
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <Xm/List.h>
-#include "XdbPrintTree.c"
+
+#include "../../common/Test.h"
 
 char *days[] = { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday",
 		     "Friday", "Saturday" };
