@@ -1,11 +1,13 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/list/test8.c,v 1.8 2002/05/01 15:39:21 amai Exp $ */
 /* test how lesstif handles a list with no elements -- DEFECT 1*/
 
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <Xm/List.h>
-#include "XdbPrintTree.c"
 
 #include "../../common/Test.h"
-#include "../../common/DumpLayout.h"
+
 
 int
 main(int argc, char **argv)
