@@ -1,4 +1,5 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/messagebox/test15.c,v 1.6 2002/02/20 17:19:04 amai Exp $
+  
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,12 +7,13 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/MessageB.h>
 
-void 
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
@@ -30,13 +32,13 @@ main(int argc, char *argv[])
 	w = XtCreateWidget("name", xmMessageBoxWidgetClass, shell, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)(after - before) > 0)
 	{
 	    if (iter != 0)
 	    {
 	      /* printf("%i %i %p %i\n", iter, iter - diff, after -
 		 before, (after - before) / (iter - diff)); */
-		total += (int)after - (int)before;
+		total += (int)(after -before);
 	    }
 	    diff = iter;
 	}
