@@ -1,3 +1,4 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/scale/test17.c,v 1.7 2001/05/28 08:22:59 amai Exp $ */
 /*
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
@@ -6,12 +7,16 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/Scale.h>
 
-void 
+
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
@@ -24,19 +29,19 @@ main(int argc, char *argv[])
 
     shell = XtAppInitialize(&app, "Test", NULL, 0,
 			    &argc, argv, NULL, NULL, 0);
-    while (iter < 1000)
+    while (iter < 10000)
     {
 	before = sbrk((ptrdiff_t) 0);
 	w = XtCreateWidget("name", xmScaleWidgetClass, shell, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)((char *)after - (char *)before) > 0)
 	{
 	    if (iter != 0)
 	    {
 	      /* printf("%i %i %p %i\n", iter, iter - diff, after -
 		 before, (after - before) / (iter - diff)); */
-		total += (int)after - (int)before;
+		total += (int)((char *)after - (char *)before);
 	    }
 	    diff = iter;
 	}
