@@ -1,16 +1,26 @@
-/* $Header: /cvsroot/lesstif/lesstif/test/Xm/scrolledwindow/test13.c,v 1.5 2001/05/23 14:30:30 amai Exp $
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/scrolledwindow/test13.c,v 1.6 2001/06/18 14:22:06 amai Exp $
  * This test is an interactive interface to control the resources
  * of a bunch of widgets. These widgets are really stolen out of
  * test12.
  */
+
+#include <stdlib.h>
 #include <stdio.h>
-#include <Xm/XmAll.h>
-#include <Xm/ScrolledWP.h>
+
+#include <Xm/Xm.h>
 #include <Xm/ArrowB.h>
+#include <Xm/CascadeB.h>
+#include <Xm/Form.h>
+#include <Xm/PushB.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Scale.h>
+#include <Xm/ScrolledWP.h>
+
 #ifdef LESSTIF_VERSION
 #include <XmI/MacrosI.h>
 #endif
 
+
 Widget toplevel, sw, ab;
 Dimension st;
 
